-- $Id: Atlas_Transportation.lua 34 2016-08-24 05:21:47Z arith $
--[[

	Atlas, a World of Warcraft instance map browser
	Copyright 2005 ~ 2010 - Dan Gilbert <dan.b.gilbert@gmail.com>
	Copyright 2010 - Lothaer <lothayer@gmail.com>, Atlas Team
	Copyright 2011 ~ 2016 - Arith Hsu, Atlas Team <atlas.addon@gmail.com>

	This file is part of Atlas.

	Atlas is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	Atlas is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with Atlas; if not, write to the Free Software
	Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

--]]


local BZ = Atlas_GetLocaleLibBabble("LibBabble-SubZone-3.0");
local BF = Atlas_GetLocaleLibBabble("LibBabble-Faction-3.0");
local L = LibStub("AceLocale-3.0"):GetLocale("Atlas_Transportation");
local ALC = LibStub("AceLocale-3.0"):GetLocale("Atlas");

local BLUE = "|cff6666ff";
local GREN = "|cff66cc33";
local _RED = "|cffcc3333";
local ORNG = "|cffcc9933";
local PURP = "|cff9900ff";
local WHIT = "|cffffffff";
local CYAN = "|cff00ffff";
local GREY = "|cff999999";
local ALAN = "|cff7babe0"; -- Alliance's taxi node
local HRDE = "|cffda6955"; -- Horde's taxi node
local NUTL = "|cfffee570"; -- Nutral taxi node
local INDENT = "      ";

local myCategory = L["Transportation Maps"];

local myData = {
	TransAllianceBrokenIsles = {
		ZoneName = { BZ["Broken Isles"]..ALC["L-Parenthesis"]..FACTION_ALLIANCE..ALC["R-Parenthesis"] };
		WorldMapID = "1007";
		Faction = "Alliance";
		{ _RED..L["Portals"] };
		{ PURP.." A) "..BZ["Greyfang Enclave"], 10038 };
		{ INDENT..PURP.."  -> "..BZ["Ironforge"]..ALC["Comma"]..BZ["Dun Morogh"]..ALC["Comma"]..BZ["Eastern Kingdoms"] };
		{ INDENT..PURP.." <-> "..BZ["Stormwind City"]..ALC["Comma"]..BZ["Elwynn Forest"]..ALC["Comma"]..BZ["Eastern Kingdoms"] };
		{ INDENT..PURP.."  -> "..BZ["Shrine of Seven Stars"]..ALC["Comma"]..BZ["Vale of Eternal Blossoms"]..ALC["Comma"]..BZ["Pandaria"] };
		{ INDENT..PURP.."  -> "..BZ["The Exodar"]..ALC["Comma"]..BZ["Azuremyst Isle"]..ALC["Comma"]..BZ["Kalimdor"] };
		{ INDENT..PURP.."  -> "..BZ["Darnassus"]..ALC["Comma"]..BZ["Teldrassil"]..ALC["Comma"]..BZ["Kalimdor"] };
		{ PURP.." B) "..BZ["Chamber of the Guardian"], 10039 };
		{ INDENT..PURP.."  -> "..BZ["Caverns of Time"]..ALC["Comma"]..BZ["Tanaris"]..ALC["Comma"]..BZ["Kalimdor"] };
		{ INDENT..PURP.."  -> "..BZ["Shattrath City"]..ALC["Comma"]..BZ["Terokkar Forest"]..ALC["Comma"]..BZ["Outland"] };
		{ INDENT..PURP.."  -> "..BZ["Wyrmrest Temple"]..ALC["Comma"]..BZ["Dragonblight"]..ALC["Comma"]..BZ["Northrend"] };
		{ INDENT..PURP.."  -> "..BZ["Dalaran Crater"]..ALC["Comma"]..BZ["Hillsbrad Foothills"]..ALC["Comma"]..BZ["Eastern Kingdoms"] };
		{ INDENT..INDENT.._RED..ALC["L-Parenthesis"]..L["Warning: Drop"]..ALC["R-Parenthesis"] };
		{ INDENT..PURP.."  -> "..BZ["Karazhan"]..ALC["Comma"]..BZ["Deadwind Pass"]..ALC["Comma"]..BZ["Eastern Kingdoms"] };
		{ "" };
		{ _RED..L["Taxi Nodes"] };
		{ BLUE..BZ["Dalaran"] };
		{ NUTL.." 1) "..BZ["Krasus' Landing"], 10001 };
		{ "" };
		{ BLUE..BZ["Azsuna"] };
		{ NUTL.." 2) "..BZ["Watchers' Aerie"], 10002 };
		{ NUTL.." 3) "..BZ["Wardens' Redoubt"], 10003 };
		{ NUTL.." 4) "..BZ["Shackle's Den"], 10004 };
		{ NUTL.." 5) "..BZ["Illidari Stand"], 10005 };
		{ NUTL.." 6) "..BZ["Illidari Perch"], 10006 };
		{ NUTL.." 7) "..BZ["Felblaze Ingress"], 10007 };
		{ NUTL.." 8) "..BZ["Azurewing Repose"], 10008 };
		{ NUTL.." 9) "..BZ["Challiane's Terrace"], 10009 };
		{ NUTL.."10) "..BZ["Eye of Azshara"], 10010 };
		{ "" };
		{ BLUE..BZ["Val'sharah"] };
		{ NUTL.."11) "..BZ["Lorlathil"], 10011 };
		{ NUTL.."12) "..BZ["Gloaming Reef"], 10012 };
		{ NUTL.."13) "..BZ["Bradensbrook"], 10013 };
		{ NUTL.."14) "..BZ["Garden of the Moon"], 10014 };
		{ NUTL.."15) "..BZ["Starsong Refuge"], 10015 };
		{ GREN.." 1) "..BZ["The Dreamgrove"]..ALC["L-Parenthesis"]..L["Druid Only"]..ALC["R-Parenthesis"], 10100 };
		{ "" };
		{ BLUE..BZ["Highmountain"] };
		{ NUTL.."16) "..BZ["Obsidian Overlook"], 10016 };
		{ NUTL.."17) "..BZ["Ironhorn Enclave"], 10017 };
		{ NUTL.."18) "..BZ["Sylvan Falls"], 10018 };
		{ NUTL.."19) "..BZ["Thunder Totem"], 10019 };
		{ NUTL.."20) "..BZ["Stonehoof Watch"], 10020 };
		{ NUTL.."21) "..BZ["Nesingwary"], 10021 };
		{ NUTL.."22) "..BZ["Skyhorn"], 10022 };
		{ NUTL.."23) "..BZ["Felbane Camp"], 10023 };
		{ NUTL.."24) "..BZ["The Witchwood"], 10024 };
		{ NUTL.."25) "..BZ["Prepfoot"], 10025 };
		{ NUTL.."26) "..BZ["Shipwreck Cove"], 10026 };
		{ GREN.." 2) "..BZ["Trueshot Lodge"]..ALC["L-Parenthesis"]..L["Hunter Only"]..ALC["R-Parenthesis"], 10101 };
		{ "" };
		{ BLUE..BZ["Stormheim"] };
		{ ALAN.."27) "..BZ["Skyfire Triage Camp"], 10027 };
		{ ALAN.."28) "..BZ["Lorna's Watch"], 10028 };
		{ NUTL.."29) "..BZ["Stormtorn Foothills"], 10029 };
		{ NUTL.."30) "..BZ["Valdisdall"], 10030 };
		{ ALAN.."31) "..BZ["Greywatch"], 10031 };
		{ NUTL.."32) "..BZ["Shield's Rest"], 10032 };
		{ NUTL.."33) "..BZ["Hafr Fjall"], 10033 };
		{ "" };
		{ BLUE..BZ["Suramar"] };
		{ NUTL.."34) "..BZ["Irongrove Retreat"], 10034 };
		{ NUTL.."35) "..BZ["Meredil"], 10035 };
		{ NUTL.."36) "..BZ["Crimson Thicket"], 10036 };
		{ "" };
		{ BLUE..BZ["Broken Shore"] };
		{ NUTL.."37) "..BZ["Illidari Camp"], 10037 };
		{ GREN.." 3) "..BZ["Acherus: The Ebon Hold"]..ALC["L-Parenthesis"]..L["Death Knight Only"]..ALC["R-Parenthesis"], 10102 };
		{ "" };
		{ _RED..L["Legend"] };
		{ PURP..L["Purple"]..ALC["Colon"]..L["Portals"] };
		{ NUTL..L["Yellow"]..ALC["Colon"]..L["Taxi Nodes"]..ALC["Hyphen"]..L["Nutral"] };
		{ ALAN..L["Blue"]..ALC["Colon"]..L["Taxi Nodes"]..ALC["Hyphen"]..FACTION_ALLIANCE };
		{ GREN..L["Green"]..ALC["Colon"]..L["Taxi Nodes"]..ALC["Hyphen"]..L["Druid Only"] };
	};
	TransHordeBrokenIsles = {
		ZoneName = { BZ["Broken Isles"]..ALC["L-Parenthesis"]..FACTION_HORDE..ALC["R-Parenthesis"] };
		WorldMapID = "1007";
		Faction = "Horde";
		{ _RED..L["Portals"] };
		{ PURP.." A) "..BZ["Windrunner's Sanctuary"], 10038 };
		{ INDENT..PURP.." <-> "..BZ["Orgrimmar"]..ALC["Comma"]..BZ["Durotar"]..ALC["Comma"]..BZ["Kalimdor"] };
		{ INDENT..PURP.."  -> "..BZ["Thunder Bluff"]..ALC["Comma"]..BZ["Mulgore"]..ALC["Comma"]..BZ["Kalimdor"] };
		{ INDENT..PURP.."  -> "..BZ["Shrine of Two Moons"]..ALC["Comma"]..BZ["Vale of Eternal Blossoms"]..ALC["Comma"]..BZ["Pandaria"] };
		{ INDENT..PURP.."  -> "..BZ["Undercity"]..ALC["Comma"]..BZ["Tirisfal Glades"]..ALC["Comma"]..BZ["Eastern Kingdoms"] };
		{ INDENT..PURP.."  -> "..BZ["Silvermoon City"]..ALC["Comma"]..BZ["Eversong Woods"]..ALC["Comma"]..BZ["Eastern Kingdoms"] };
		{ PURP.." B) "..BZ["Chamber of the Guardian"], 10039 };
		{ INDENT..PURP.."  -> "..BZ["Caverns of Time"]..ALC["Comma"]..BZ["Tanaris"]..ALC["Comma"]..BZ["Kalimdor"] };
		{ INDENT..PURP.."  -> "..BZ["Shattrath City"]..ALC["Comma"]..BZ["Terokkar Forest"]..ALC["Comma"]..BZ["Outland"] };
		{ INDENT..PURP.."  -> "..BZ["Wyrmrest Temple"]..ALC["Comma"]..BZ["Dragonblight"]..ALC["Comma"]..BZ["Northrend"] };
		{ INDENT..PURP.."  -> "..BZ["Dalaran Crater"]..ALC["Comma"]..BZ["Hillsbrad Foothills"]..ALC["Comma"]..BZ["Eastern Kingdoms"] };
		{ INDENT..INDENT.._RED..ALC["L-Parenthesis"]..L["Warning: Drop"]..ALC["R-Parenthesis"] };
		{ INDENT..PURP.."  -> "..BZ["Karazhan"]..ALC["Comma"]..BZ["Deadwind Pass"]..ALC["Comma"]..BZ["Eastern Kingdoms"] };
		{ "" };
		{ _RED..L["Taxi Nodes"] };
		{ BLUE..BZ["Dalaran"] };
		{ NUTL.." 1) "..BZ["Krasus' Landing"], 10001 };
		{ "" };
		{ BLUE..BZ["Azsuna"] };
		{ NUTL.." 2) "..BZ["Watchers' Aerie"], 10002 };
		{ NUTL.." 3) "..BZ["Wardens' Redoubt"], 10003 };
		{ NUTL.." 4) "..BZ["Shackle's Den"], 10004 };
		{ NUTL.." 5) "..BZ["Illidari Stand"], 10005 };
		{ NUTL.." 6) "..BZ["Illidari Perch"], 10006 };
		{ NUTL.." 7) "..BZ["Felblaze Ingress"], 10007 };
		{ NUTL.." 8) "..BZ["Azurewing Repose"], 10008 };
		{ NUTL.." 9) "..BZ["Challiane's Terrace"], 10009 };
		{ NUTL.."10) "..BZ["Eye of Azshara"], 10010 };
		{ "" };
		{ BLUE..BZ["Val'sharah"] };
		{ NUTL.."11) "..BZ["Lorlathil"], 10011 };
		{ NUTL.."12) "..BZ["Gloaming Reef"], 10012 };
		{ NUTL.."13) "..BZ["Bradensbrook"], 10013 };
		{ NUTL.."14) "..BZ["Garden of the Moon"], 10014 };
		{ NUTL.."15) "..BZ["Starsong Refuge"], 10015 };
		{ GREN.." 1) "..BZ["The Dreamgrove"]..ALC["L-Parenthesis"]..L["Druid Only"]..ALC["R-Parenthesis"], 10100 };
		{ "" };
		{ BLUE..BZ["Highmountain"] };
		{ NUTL.."16) "..BZ["Obsidian Overlook"], 10016 };
		{ NUTL.."17) "..BZ["Ironhorn Enclave"], 10017 };
		{ NUTL.."18) "..BZ["Sylvan Falls"], 10018 };
		{ NUTL.."19) "..BZ["Thunder Totem"], 10019 };
		{ NUTL.."20) "..BZ["Stonehoof Watch"], 10020 };
		{ NUTL.."21) "..BZ["Nesingwary"], 10021 };
		{ NUTL.."22) "..BZ["Skyhorn"], 10022 };
		{ NUTL.."23) "..BZ["Felbane Camp"], 10023 };
		{ NUTL.."24) "..BZ["The Witchwood"], 10024 };
		{ NUTL.."25) "..BZ["Prepfoot"], 10025 };
		{ NUTL.."26) "..BZ["Shipwreck Cove"], 10026 };
		{ GREN.." 2) "..BZ["Trueshot Lodge"]..ALC["L-Parenthesis"]..L["Hunter Only"]..ALC["R-Parenthesis"], 10101 };
		{ "" };
		{ BLUE..BZ["Stormheim"] };
		{ HRDE.."27) "..BZ["Forsaken Foothold"], 10027 };
		{ HRDE.."28) "..BZ["Cullen's Post"], 10028 };
		{ NUTL.."29) "..BZ["Stormtorn Foothills"], 10029 };
		{ NUTL.."30) "..BZ["Valdisdall"], 10030 };
		{ HRDE.."31) "..BZ["Dreadwake's Landing"], 10031 };
		{ NUTL.."32) "..BZ["Shield's Rest"], 10032 };
		{ NUTL.."33) "..BZ["Hafr Fjall"], 10033 };
		{ "" };
		{ BLUE..BZ["Suramar"] };
		{ NUTL.."34) "..BZ["Irongrove Retreat"], 10034 };
		{ NUTL.."35) "..BZ["Meredil"], 10035 };
		{ NUTL.."36) "..BZ["Crimson Thicket"], 10036 };
		{ "" };
		{ BLUE..BZ["Broken Shore"] };
		{ NUTL.."37) "..BZ["Illidari Camp"], 10037 };
		{ GREN.." 3) "..BZ["Acherus: The Ebon Hold"]..ALC["L-Parenthesis"]..L["Death Knight Only"]..ALC["R-Parenthesis"], 10102 };
		{ "" };
		{ _RED..L["Legend"] };
		{ PURP..L["Purple"]..ALC["Colon"]..L["Portals"] };
		{ NUTL..L["White"]..ALC["Colon"]..L["Taxi Nodes"]..ALC["Hyphen"]..L["Nutral"] };
		{ HRDE..L["Red"]..ALC["Colon"]..L["Taxi Nodes"]..ALC["Hyphen"]..FACTION_HORDE };
		{ GREN..L["Green"]..ALC["Colon"]..L["Taxi Nodes"]..ALC["Hyphen"]..L["Druid Only"] };
	};
	TransAllianceDraenor = {
		ZoneName = { BZ["Draenor"]..ALC["L-Parenthesis"]..FACTION_ALLIANCE..ALC["R-Parenthesis"] };
		WorldMapID = "962";
		Faction = "Alliance";
		{ _RED..L["Portals"] };
		{ PURP.." A) "..BZ["Khadgar's Tower"]..ALC["Comma"]..BZ["Talador"], 10052 };
		{ PURP.." A') "..BZ["Darnassus"]..ALC["Comma"]..BZ["Teldrassil"]..ALC["Comma"]..BZ["Kalimdor"], 10053 };
		{ PURP.." B') "..BZ["Ironforge"]..ALC["Comma"]..BZ["Dun Morogh"]..ALC["Comma"]..BZ["Eastern Kingdoms"], 10054 };
		{ PURP.." C') "..BZ["Stormwind City"]..ALC["Comma"]..BZ["Elwynn Forest"]..ALC["Comma"]..BZ["Eastern Kingdoms"], 10055 };
		{ NUTL.."19) "..BZ["Zangarra"]..ALC["Comma"]..BZ["Talador"] };
		{ "" };
		{ _RED..L["Taxi Nodes"] };
		{ BLUE..BZ["Shadowmoon Valley"] };
		{ ALAN.." 1) "..BZ["Lunarfall"], 10001 };
		{ NUTL.." 2) "..BZ["Exile's Rise"], 10002 };
		{ ALAN.." 3) "..BZ["Embaari Village"], 10003 };
		{ ALAN.." 4) "..BZ["Path of Light"], 10004 };
		{ ALAN.." 5) "..BZ["Elodor"], 10005 };
		{ ALAN.." 6) "..BZ["Tranquil Court"], 10006 };
		{ ALAN.." 7) "..BZ["The Draakorium"], 10007 };
		{ ALAN.." 8) "..BZ["Twilight Glade"], 10008 };
		{ NUTL.." 9) "..BZ["Socrethar's Rise"], 10009 };
		{ NUTL.."10) "..BZ["Darktide Roost"], 10010 };
		{ NUTL.."11) "..BZ["Akeeta's Hovel"], 10011 };
		{ "" };
		{ BLUE..BZ["Talador"] };
		{ ALAN.."12) "..BZ["Anchorite's Sojourn"], 10012 };
		{ NUTL.."13) "..BZ["Terokkar Refuge"], 10013 };
		{ ALAN.."14) "..BZ["Exarch's Refuge"], 10014 };
		{ NUTL.."15) "..BZ["Retribution Point"], 10015 };
		{ NUTL.."16) "..BZ["Shattrath City"], 10016 };
		{ ALAN.."17) "..BZ["Redemption Rise"], 10017 };
		{ ALAN.."18) "..BZ["Fort Wrynn"], 10018 };
		{ NUTL.."19) "..BZ["Zangarra"], 10019 };
		{ "" };
		{ BLUE..BZ["Gorgrond"] };
		{ ALAN.."20) "..BZ["Bastion Rise"], 10020 };
		{ ALAN.."21) "..BZ["Deeproot"], 10021 };
		{ ALAN.."22) "..BZ["Highpass"], 10022 };
		{ ALAN.."23) "..BZ["Wildwood Wash"], 10023 };
		{ NUTL.."24) "..BZ["Everbloom Wilds"], 10024 };
		{ NUTL.."25) "..BZ["Everbloom Overlook"], 10025 };
		{ NUTL.."26) "..BZ["Breaker's Crown"], 10026 };
		{ NUTL.."27) "..BZ["Skysea Point"], 10027 };
		{ NUTL.."28) "..BZ["Iron Docks"], 10028 };
		{ "" };
		{ BLUE..BZ["Spires of Arak"] };
		{ NUTL.."29) "..BZ["Apexis Excavation"], 10029 };
		{ ALAN.."30) "..BZ["Southport"], 10030 };
		{ NUTL.."31) "..BZ["Veil Terokk"], 10031 };
		{ NUTL.."32) "..BZ["Crow's Crook"], 10032 };
		{ NUTL.."33) "..BZ["Talon Watch"], 10033 };
		{ NUTL.."34) "..BZ["Pinchwhistle Gearworks"], 10034 };
		{ "" };
		{ BLUE..BZ["Nagrand"] };
		{ NUTL.."35) "..BZ["The Ring of Trials"], 10035 };
		{ ALAN.."36) "..BZ["Telaari Station"], 10036 };
		{ NUTL.."37) "..BZ["Nivek's Overlook"], 10037 };
		{ ALAN.."38) "..BZ["Yrel's Watch"], 10038 };
		{ NUTL.."39) "..BZ["Rilzit's Holdfast"], 10039 };
		{ NUTL.."40) "..BZ["Joz's Rylaks"], 10040 };
		{ NUTL.."41) "..BZ["Throne of the Elements"], 10041 };
		{ "" };
		{ BLUE..BZ["Frostfire Ridge"] };
		{ ALAN.."42) "..BZ["Iron Siegeworks"], 10042 };
		{ NUTL.."43) "..BZ["Bloodmaul Slag Mines"], 10043 };
		{ "" };
		{ BLUE..BZ["Ashran"] };
		{ ALAN.."44) "..BZ["Stormshield"], 10044 };
		{ "" };
		{ BLUE..BZ["Tanaan Jungle"] };
		{ ALAN.."45) "..BZ["The Iron Front"], 10045 };
		{ NUTL.."46) "..BZ["Sha'naari Refuge"], 10046 };
		{ NUTL.."47) "..BZ["Malo's Lookout"], 10047 };
		{ ALAN.."48) "..BZ["Lion's Watch"], 10048 };
		{ NUTL.."49) "..BZ["Aktar's Post"], 10049 };
		{ NUTL.."50) "..BZ["Vault of the Earth"], 10050 };
		{ NUTL.."51) "..BZ["Throne of Kil'jaeden"], 10051 };
		{ "" };
		{ _RED..L["Legend"] };
		{ PURP..L["Purple"]..ALC["Colon"]..L["Portals"] };
		{ NUTL..L["Yellow"]..ALC["Colon"]..L["Taxi Nodes"]..ALC["Hyphen"]..L["Nutral"] };
		{ ALAN..L["Blue"]..ALC["Colon"]..L["Taxi Nodes"]..ALC["Hyphen"]..FACTION_ALLIANCE };
		{ WHIT..L["White"]..ALC["Colon"]..L["Special transportation"] };
		{ PURP.."-- : "..L["Portal / Waygate Path to the destination"] };
		{ CYAN.."-- : "..L["Airship"] };
	};
	TransHordeDraenor = {
		ZoneName = { BZ["Draenor"]..ALC["L-Parenthesis"]..FACTION_HORDE..ALC["R-Parenthesis"] };
		WorldMapID = "962";
		Faction = "Horde";
		{ _RED..L["Portals"] };
		{ PURP.." A) "..BZ["Khadgar's Tower"]..ALC["Comma"]..BZ["Talador"], 10051 };
		{ PURP.." A') "..BZ["Orgrimmar"]..ALC["Comma"]..BZ["Durotar"]..ALC["Comma"]..BZ["Kalimdor"], 10052 };
		{ PURP.." B') "..BZ["Thunder Bluff"]..ALC["Comma"]..BZ["Mulgore"]..ALC["Comma"]..BZ["Kalimdor"], 10053 };
		{ PURP.." C') "..BZ["Undercity"]..ALC["Comma"]..BZ["Tirisfal Glades"]..ALC["Comma"]..BZ["Eastern Kingdoms"], 10054 };
		{ NUTL.."18) "..BZ["Zangarra"]..ALC["Comma"]..BZ["Talador"] };
		{ "" };
		{ _RED..L["Taxi Nodes"] };
		{ BLUE..BZ["Frostfire Ridge"] };
		{ HRDE.." 1) "..BZ["Frostwall Garrison"], 10001 };
		{ HRDE.." 2) "..BZ["Wor'gol"], 10002 };
		{ HRDE.." 3) "..BZ["Bladespire Fortress"], 10003 };
		{ HRDE.." 4) "..BZ["Stonefang Outpost"], 10004 };
		{ HRDE.." 5) "..BZ["Throm'Var"], 10005 };
		{ HRDE.." 6) "..BZ["Darkspear's Edge"], 10006 };
		{ NUTL.." 7) "..BZ["Bloodmaul Slag Mines"], 10007 };
		{ HRDE.." 8) "..BZ["Wolf's Stand"], 10008 };
		{ HRDE.." 9) "..BZ["Thunder Pass"], 10009 };
		{ "" };
		{ BLUE..BZ["Gorgrond"] };
		{ HRDE.."10) "..BZ["Evermorn Springs"], 10010 };
		{ HRDE.."11) "..BZ["Bastion Rise"], 10011 };
		{ HRDE.."12) "..BZ["Beastwatch"], 10012 };
		{ NUTL.."13) "..BZ["Breaker's Crown"], 10013 };
		{ NUTL.."14) "..BZ["Skysea Point"], 10014 };
		{ NUTL.."15) "..BZ["Iron Docks"], 10015 };
		{ NUTL.."16) "..BZ["Everbloom Wilds"], 10016 };
		{ NUTL.."17) "..BZ["Everbloom Overlook"], 10017 };
		{ "" };
		{ BLUE..BZ["Talador"] };
		{ NUTL.."18) "..BZ["Zangarra"], 10018 };
		{ HRDE.."19) "..BZ["Vol'jin's Pride"], 10019 };
		{ HRDE.."20) "..BZ["Frostwolf Overlook"], 10020 };
		{ HRDE.."21) "..BZ["Durotan's Grasp"], 10021 };
		{ NUTL.."22) "..BZ["Shattrath City"], 10022 };
		{ NUTL.."23) "..BZ["Terokkar Refuge"], 10023 };
		{ HRDE.."24) "..BZ["Exarch's Refuge"], 10024 };
		{ NUTL.."25) "..BZ["Retribution Point"], 10025 };
		{ "" };
		{ BLUE..BZ["Spires of Arak"] };
		{ NUTL.."26) "..BZ["Apexis Excavation"], 10026 };
		{ NUTL.."27) "..BZ["Crow's Crook"], 10027 };
		{ HRDE.."28) "..BZ["Axefall"], 10028 };
		{ NUTL.."29) "..BZ["Veil Terokk"], 10029 };
		{ NUTL.."30) "..BZ["Talon Watch"], 10030 };
		{ NUTL.."31) "..BZ["Pinchwhistle Gearworks"], 10031 };
		{ "" };
		{ BLUE..BZ["Nagrand"] };
		{ NUTL.."32) "..BZ["Wor'var"], 10032 };
		{ HRDE.."33) "..BZ["The Ring of Trials"], 10033 };
		{ NUTL.."34) "..BZ["Throne of the Elements"], 10034 };
		{ NUTL.."35) "..BZ["Joz's Rylaks"], 10035 };
		{ NUTL.."36) "..BZ["Rilzit's Holdfast"], 10036 };
		{ HRDE.."37) "..BZ["Riverside Post"], 10037 };
		{ NUTL.."38) "..BZ["Nivek's Overlook"], 10038 };
		{ "" };
		{ BLUE..BZ["Shadowmoon Valley"] };
		{ NUTL.."39) "..BZ["Akeeta's Hovel"], 10039 };
		{ NUTL.."40) "..BZ["Exile's Rise"], 10040 };
		{ NUTL.."41) "..BZ["Socrethar's Rise"], 10041 };
		{ NUTL.."42) "..BZ["Darktide Roost"], 10042 };
		{ "" };
		{ BLUE..BZ["Ashran"] };
		{ HRDE.."43) "..BZ["Warspear"], 10043 };
		{ "" };
		{ BLUE..BZ["Tanaan Jungle"] };
		{ HRDE.."44) "..BZ["The Iron Front"], 10044 };
		{ NUTL.."45) "..BZ["Sha'naari Refuge"], 10045 };
		{ NUTL.."46) "..BZ["Vault of the Earth"], 10046 };
		{ HRDE.."47) "..BZ["Vol'mar"], 10047 };
		{ NUTL.."48) "..BZ["Aktar's Post"], 10048 };
		{ NUTL.."49) "..BZ["Malo's Lookout"], 10049 };
		{ WHIT.."50) "..BZ["Throne of Kil'jaeden"], 10050 };
		{ "" };
		{ PURP..L["Purple"]..ALC["Colon"]..L["Portals"] };
		{ NUTL..L["Yellow"]..ALC["Colon"]..L["Taxi Nodes"]..ALC["Hyphen"]..L["Nutral"] };
		{ HRDE..L["Red"]..ALC["Colon"]..L["Taxi Nodes"]..ALC["Hyphen"]..FACTION_HORDE };
		{ WHIT..L["White"]..ALC["Colon"]..L["Special transportation"] };
		{ PURP.."-- : "..L["Portal / Waygate Path to the destination"] };
		{ CYAN.."-- : "..L["Airship"] };
	};
	TransAllianceAshran = {
		ZoneName = { BZ["Ashran"]..ALC["L-Parenthesis"]..FACTION_ALLIANCE..ALC["R-Parenthesis"] };
		WorldMapID = "1009";
		Faction = "Alliance";
		{ _RED..L["Taxi Nodes"] };
		{ WHIT.." A) "..BZ["Stormshield"], 10001 };
		{ "" };
		{ _RED..L["Portals"] };
		{ PURP.." B) "..BZ["Lion's Watch"], 10002 };
		{ PURP.." C) "..BZ["Ironforge"], 10003 };
		{ PURP.." D) "..BZ["Stormwind City"], 10004 };
		{ PURP.." E) "..BZ["Darnassus"], 10005 };
	};
	TransHordeAshran = {
		ZoneName = { BZ["Ashran"]..ALC["L-Parenthesis"]..FACTION_HORDE..ALC["R-Parenthesis"] };
		WorldMapID = "1011";
		Faction = "Horde";
		{ _RED..L["Taxi Nodes"] };
		{ WHIT.." A) "..BZ["Warspear"], 10001 };
		{ "" };
		{ _RED..L["Portals"] };
		{ PURP.." B) "..BZ["Vol'mar"], 10002 };
		{ PURP.." C) "..BZ["Thunder Bluff"], 10003 };
		{ PURP.." D) "..BZ["Undercity"], 10004 };
		{ PURP.." E) "..BZ["Orgrimmar"], 10005 };
	};
	TransAllianceEast = {
		ZoneName = { BZ["Eastern Kingdoms"]..ALC["L-Parenthesis"]..FACTION_ALLIANCE..ALC["R-Parenthesis"] };
		WorldMapID = "14";
		Faction = "Alliance";
		{ _RED..BZ["Docks"] };
		{ ORNG.." A') "..BZ["Valgarde"]..ALC["Comma"]..BZ["Howling Fjord"]..ALC["Comma"]..BZ["Northrend"] };
		{ ORNG.." B') "..BZ["Valiance Keep"]..ALC["Comma"]..BZ["Borean Tundra"]..ALC["Comma"]..BZ["Northrend"] };
		{ ORNG.." C') "..BZ["Rut'theran Village"]..ALC["Comma"]..BZ["Teldrassil"]..ALC["Comma"]..BZ["Kalimdor"] };
		{ ORNG.." D') "..BZ["Ratchet"]..ALC["Comma"]..BZ["Northern Barrens"]..ALC["Comma"]..BZ["Kalimdor"] };
		{ ORNG.." E') "..BZ["Theramore"]..ALC["Comma"]..BZ["Dustwallow Marsh"]..ALC["Comma"]..BZ["Kalimdor"] };
		{ WHIT.."21) "..BZ["Menethil Harbor"]..ALC["Comma"]..BZ["Wetlands"] };
		{ WHIT.."43) "..BZ["Stormwind Harbor"]..ALC["Comma"]..BZ["Elwynn Forest"] };
		{ WHIT.."60) "..BZ["Booty Bay"]..ALC["Comma"]..BZ["The Cape of Stranglethorn"] };
		{ "" };
		{ _RED..L["Portals"]..ALC["Slash"]..L["Transporter"] };
		{ PURP.." A) "..BZ["Baradin Base Camp"]..ALC["Comma"]..BZ["Tol Barad Peninsula"] };
		{ PURP.." B) "..BZ["Baradin Hold"]..ALC["Comma"]..BZ["Tol Barad"] };
		{ GREY..INDENT..ALC["L-Parenthesis"]..L["Only available after winning the PvP battle"]..ALC["R-Parenthesis"] };
		{ PURP.." C) "..BZ["Highbank"]..ALC["Comma"]..BZ["Twilight Highlands"] };
		{ PURP.." D) "..BZ["Fuselight-by-the-Sea"]..ALC["Comma"]..BZ["Badlands"] };
		{ GREY..INDENT..ALC["L-Parenthesis"]..L["Transporters by the sea and on the cliff"]..ALC["R-Parenthesis"] };
		{ PURP.." A') "..BZ["Ashran"]..ALC["Comma"]..BZ["Draenor"] };
		{ PURP.." B') "..BZ["Nordrassil"]..ALC["Comma"]..BZ["Mount Hyjal"]..ALC["Comma"]..BZ["Kalimdor"] };
		{ PURP.." C') "..BZ["Ramkahen"]..ALC["Comma"]..BZ["Uldum"]..ALC["Comma"]..BZ["Kalimdor"] };
		{ PURP.." D') "..BZ["The Stair of Destiny"]..ALC["Comma"]..BZ["Hellfire Peninsula"]..ALC["Comma"]..BZ["Outland"] };
		{ PURP.." E') "..BZ["Temple of Earth"]..ALC["Comma"]..BZ["Deepholm"] };
		{ PURP.." F') "..BZ["Darkmoon Island"] };
		{ PURP.." G') "..BZ["Paw'Don Village"]..ALC["Comma"]..BZ["The Jade Forest"]..ALC["Comma"]..BZ["Pandaria"] };
		{ WHIT.."29) "..BZ["The Mystic Ward"]..ALC["Comma"]..BZ["Ironforge"]..ALC["Comma"]..BZ["Dun Morogh"] };
		{ WHIT.."43) "..BZ["Mage Quarter"]..ALC["Comma"]..BZ["Stormwind"]..ALC["Comma"]..BZ["Elwynn Forest"] };
		{ WHIT.."61) "..BZ["Shattered Beachhead"]..ALC["Comma"]..BZ["Blasted Lands"] };
		{ "" };
		{ _RED..L["Portals"]..ALC["Hyphen"]..L["Druid Only"] };
		{ GREN.." A) "..BZ["Seradane"]..ALC["Comma"]..BZ["The Hinterlands"] };
		{ GREN.." B) "..BZ["Twilight Grove"]..ALC["Comma"]..BZ["Duskwood"] };
		{ "" };
		{ _RED..L["Taxi Nodes"] };
		{ BLUE..BZ["Isle of Quel'Danas"] };
		{ WHIT.." 1) "..BZ["Shattered Sun Staging Area"] };
		{ "" };
		{ BLUE..BZ["Ghostlands"] };
		{ WHIT.." 2) "..BZ["Zul'Aman"] };
		{ "" };
		{ BLUE..BZ["Eastern Plaguelands"] };
		{ GREN.." 3) "..BZ["Acherus: The Ebon Hold"]..ALC["L-Parenthesis"]..L["Death Knight Only"]..ALC["R-Parenthesis"] };
		{ WHIT.." 4) "..BZ["Light's Hope Chapel"] };
		{ WHIT.." 5) "..BZ["Eastwall Tower"] };
		{ WHIT.." 6) "..BZ["Northpass Tower"] };
		{ WHIT.." 7) "..BZ["Plaguewood Tower"] };
		{ WHIT.." 8) "..BZ["Light's Shield Tower"] };
		{ WHIT.." 9) "..BZ["Crown Guard Tower"] };
		{ WHIT.."10) "..BZ["Thondroril River"] };
		{ "" };
		{ BLUE..BZ["Western Plaguelands"] };
		{ WHIT.."11) "..BZ["Hearthglen"] };
		{ WHIT.."12) "..BZ["The Menders' Stead"] };
		{ WHIT.."13) "..BZ["Andorhal"] };
		{ GREY..INDENT..ALC["L-Parenthesis"]..L["Won't be available once the Battle for Andorhal chain is finished."]..ALC["R-Parenthesis"] };
		{ WHIT.."14) "..BZ["Chillwind Camp"] };
		{ "" };
		{ BLUE..BZ["The Hinterlands"] };
		{ WHIT.."15) "..BZ["Aerie Peak"] };
		{ WHIT.."16) "..BZ["Stormfeather Outpost"] };
		{ "" };
		{ BLUE..BZ["Arathi Highlands"] };
		{ WHIT.."17) "..BZ["Refuge Pointe"] };
		{ "" };
		{ BLUE..BZ["Wetlands"] };
		{ WHIT.."18) "..BZ["Dun Modr"] };
		{ WHIT.."19) "..BZ["Whelgar's Retreat"] };
		{ WHIT.."20) "..BZ["Greenwarden's Grove"] };
		{ WHIT.."21) "..BZ["Menethil Harbor"] };
		{ WHIT.."22) "..BZ["Slabchisel's Survey"] };
		{ "" };
		{ BLUE..BZ["Twilight Highlands"] };
		{ WHIT.."23) "..BZ["Vermillion Redoubt"] };
		{ WHIT.."24) "..BZ["Thundermar"] };
		{ WHIT.."25) "..BZ["Kirthaven"] };
		{ WHIT.."26) "..BZ["Victor's Point"] };
		{ WHIT.."27) "..BZ["Firebeard's Patrol"] };
		{ WHIT.."28) "..BZ["Highbank"] };
		{ "" };
		{ BLUE..BZ["Dun Morogh"] };
		{ WHIT.."29) "..BZ["Ironforge"] };
		{ WHIT.."30) "..BZ["Kharanos"] };
		{ WHIT.."31) "..BZ["Gol'Bolar Quarry"] };
		{ "" };
		{ BLUE..BZ["Loch Modan"] };
		{ WHIT.."32) "..BZ["Thelsamar"] };
		{ WHIT.."33) "..BZ["Farstrider Lodge"] };
		{ "" };
		{ BLUE..BZ["Searing Gorge"] };
		{ WHIT.."34) "..BZ["Thorium Point"] };
		{ WHIT.."35) "..BZ["Iron Summit"] };
		{ "" };
		{ BLUE..BZ["Badlands"] };
		{ WHIT.."36) "..BZ["Dragon's Mouth"] };
		{ WHIT.."37) "..BZ["Dustwind Dig"] };
		{ WHIT.."38) "..BZ["Fuselight"] };
		{ "" };
		{ BLUE..BZ["Burning Steppes"] };
		{ WHIT.."39) "..BZ["Chiselgrip"] };
		{ WHIT.."40) "..BZ["Morgan's Vigil"] };
		{ WHIT.."41) "..BZ["Flamestar Post"] };
		{ WHIT.."42) "..BZ["Terror Wing Path"]..ALC["Comma"]..BZ["Burning Steppes"] };
		{ WHIT..INDENT..ALC["L-Parenthesis"]..L["The Bogpaddle Bullet"]..ALC["R-Parenthesis"] };
		{ "" };
		{ BLUE..BZ["Elwynn Forest"] };
		{ WHIT.."43) "..BZ["Stormwind"] };
		{ WHIT.."44) "..BZ["Goldshire"] };
		{ WHIT.."45) "..BZ["Eastvale Logging Camp"] };
		{ "" };
		{ BLUE..BZ["Redridge Mountains"] };
		{ WHIT.."46) "..BZ["Lakeshire"] };
		{ WHIT.."47) "..BZ["Camp Everstill"] };
		{ WHIT.."48) "..BZ["Shalewind Canyon"] };
		{ "" };
		{ BLUE..BZ["Westfall"] };
		{ WHIT.."49) "..BZ["Furlbrow's Pumpkin Farm"] };
		{ WHIT.."50) "..BZ["Moonbrook"] };
		{ WHIT.."51) "..BZ["Sentinel Hill"] };
		{ "" };
		{ BLUE..BZ["Duskwood"] };
		{ WHIT.."52) "..BZ["Raven Hill"] };
		{ WHIT.."53) "..BZ["Darkshire"] };
		{ "" };
		{ BLUE..BZ["Swamp of Sorrows"] };
		{ WHIT.."54) "..BZ["The Harborage"] };
		{ WHIT.."55) "..BZ["Marshtide Watch"] };
		{ WHIT.."56) "..BZ["Bogpaddle"] };
		{ "" };
		{ BLUE..BZ["Northern Stranglethorn"] };
		{ WHIT.."57) "..BZ["Rebel Camp"] };
		{ WHIT.."58) "..BZ["Fort Livingston"] };
		{ "" };
		{ BLUE..BZ["The Cape of Stranglethorn"] };
		{ WHIT.."59) "..BZ["Explorers' League Digsite"] };
		{ WHIT.."60) "..BZ["Booty Bay"] };
		{ "" };
		{ BLUE..BZ["Blasted Lands"] };
		{ WHIT.."61) "..BZ["Nethergarde Keep"] };
		{ WHIT.."62) "..BZ["Shattered Beachhead"] };
		{ WHIT.."63) "..BZ["Surwich"] };
		{ "" };
		{ BLUE..BZ["Vashj'ir"] };
		{ CYAN.."64) "..BZ["Smuggler's Scar"]..ALC["L-Parenthesis"]..L["Seahorse"]..ALC["R-Parenthesis"] };
		{ CYAN.."65) "..BZ["Sandy Beach"]..ALC["L-Parenthesis"]..L["Seahorse"]..ALC["Slash"]..L["Gryphon"]..ALC["R-Parenthesis"] };
		{ CYAN.."66) "..BZ["Silver Tide Hollow"]..ALC["L-Parenthesis"]..L["Seahorse"]..ALC["R-Parenthesis"] };
		{ CYAN.."67) "..BZ["Tranquil Wash"]..ALC["L-Parenthesis"]..L["Seahorse"]..ALC["R-Parenthesis"] };
		{ CYAN.."68) "..BZ["Voldrin's Hold"]..ALC["L-Parenthesis"]..L["Seahorse"]..ALC["Slash"]..L["Gryphon"]..ALC["R-Parenthesis"] };
		{ CYAN.."69) "..BZ["Darkbreak Cove"]..ALC["L-Parenthesis"]..L["Seahorse"]..ALC["R-Parenthesis"] };
		{ "" };
		{ _RED..L["Legend"] };
		{ PURP.."-- : "..L["Portal / Waygate Path to the destination"] };
		{ CYAN.."-- : "..L["Ship / Zeppelin sailing path to destination"] };
		{ GREN.."-- : "..BZ["Deeprun Tram"]..ALC["Slash"]..L["Special transportation"] };
	};
	TransAllianceStormwindCity = {
		ZoneName = { BZ["Stormwind City"]..ALC["L-Parenthesis"]..FACTION_ALLIANCE..ALC["R-Parenthesis"] };
		WorldMapID = "301";
		Faction = "Alliance";
		LargeMap = "TransAllianceStormwindCity";
		{ _RED..BZ["Docks"] };
		{ ORNG.." A) "..BZ["Rut'theran Village"]..ALC["Comma"]..BZ["Teldrassil"]..ALC["Comma"]..BZ["Kalimdor"], 10001 };
		{ ORNG.." B) "..BZ["Valiance Keep"]..ALC["Comma"]..BZ["Borean Tundra"]..ALC["Comma"]..BZ["Northrend"], 10002 };
		{ "" };
		{ _RED..L["Portals"] };
		{ PURP.." A) "..BZ["The Stair of Destiny"]..ALC["Comma"]..BZ["Hellfire Peninsula"]..ALC["Comma"]..BZ["Outland"], 10003 };
		{ PURP.." B) "..BZ["Fuselight-by-the-Sea"]..ALC["Comma"]..BZ["Badlands"], 10004 };
		{ PURP.." C) "..BZ["Paw'Don Village"]..ALC["Comma"]..BZ["The Jade Forest"]..ALC["Comma"]..BZ["Pandaria"], 10005 };
		{ PURP.." D) "..BZ["Baradin Base Camp"]..ALC["Comma"]..BZ["Tol Barad Peninsula"], 10006 };
		{ PURP.." E) "..BZ["Darkbreak Cove"]..ALC["Comma"]..BZ["Vashj'ir"], 10007 };
		{ PURP.." F) "..BZ["Highbank"]..ALC["Comma"]..BZ["Twilight Highlands"], 10008 };
		{ PURP.." G) "..BZ["Nordrassil"]..ALC["Comma"]..BZ["Mount Hyjal"]..ALC["Comma"]..BZ["Kalimdor"], 10009 };
		{ PURP.." H) "..BZ["Ramkahen"]..ALC["Comma"]..BZ["Uldum"]..ALC["Comma"]..BZ["Kalimdor"], 10010 };
		{ PURP.." I) "..BZ["Temple of Earth"]..ALC["Comma"]..BZ["Deepholm"], 10011 };
		{ PURP.." J) "..BZ["Stormshield"]..ALC["Comma"]..BZ["Ashran"]..ALC["Comma"]..BZ["Draenor"], 10012 };
		{ PURP.." K) "..BZ["Dalaran"]..ALC["Comma"]..BZ["Karazhan"], 10013 };
		{ "" };
		{ _RED..DUNGEON_FLOOR_DEEPRUNTRAM1 };
		{ WHIT.." 1) "..BZ["Ironforge"], 10014 };
		{ "" };
		{ _RED..L["Taxi Nodes"] };
		{ WHIT.." 2) "..L["Gryphon Master"], 10015 };
	};
	TransAllianceWest = {
		ZoneName = { BZ["Kalimdor"]..ALC["L-Parenthesis"]..FACTION_ALLIANCE..ALC["R-Parenthesis"] };
		WorldMapID = "13";
		Faction = "Alliance";
		{ _RED..BZ["Docks"] };
		{ ORNG.." A) "..BZ["Valaar's Berth"]..ALC["Comma"]..BZ["Azuremyst Isle"] };
		{ ORNG.." A') "..BZ["Stormwind Harbor"]..ALC["Comma"]..BZ["Elwynn Forest"]..ALC["Comma"]..BZ["Eastern Kingdoms"] };
		{ ORNG.." B') "..BZ["Menethil Harbor"]..ALC["Comma"]..BZ["Wetlands"]..ALC["Comma"]..BZ["Eastern Kingdoms"] };
		{ ORNG.." C') "..BZ["Booty Bay"]..ALC["Comma"]..BZ["The Cape of Stranglethorn"]..ALC["Comma"]..BZ["Eastern Kingdoms"] };
		{ WHIT.." 3) "..BZ["Rut'theran Village"]..ALC["Comma"]..BZ["Teldrassil"] };
		{ WHIT.."28) "..BZ["Ratchet"]..ALC["Comma"]..BZ["Northern Barrens"] };
		{ WHIT.."32) "..BZ["Theramore"]..ALC["Comma"]..BZ["Dustwallow Marsh"] };
		{ "" };
		{ _RED..L["Portals"]..ALC["Slash"]..BZ["Waygate"] };
		{ PURP.." A) "..BZ["Shaper's Terrace"]..ALC["Comma"]..BZ["Un'Goro Crater"] };
		{ PURP.." B) "..BZ["Nordune Ridge"]..ALC["Comma"]..BZ["Mount Hyjal"] };
		{ PURP.." A') "..BZ["Waygate"]..ALC["Comma"]..BZ["Sholazar Basin"]..ALC["Comma"]..BZ["Northrend"] };
		{ PURP.." B') "..BZ["Molten Front"] };
		{ PURP.." C') "..BZ["Stormwind City"]..ALC["Comma"]..BZ["Elwynn Forest"]..ALC["Comma"]..BZ["Eastern Kingdoms"] };
		{ PURP.." D') "..BZ["The Stair of Destiny"]..ALC["Comma"]..BZ["Hellfire Peninsula"]..ALC["Comma"]..BZ["Outland"] };
		{ WHIT.." 2) "..BZ["Temple of the Moon"]..ALC["Comma"]..BZ["Darnassus"]..ALC["Comma"]..BZ["Teldrassil"] };
		{ WHIT.." 3) "..BZ["Rut'theran Village"]..ALC["Comma"]..BZ["Teldrassil"] };
		{ WHIT.." 5) "..BZ["The Vault of Lights"]..ALC["Comma"]..BZ["The Exodar"]..ALC["Comma"]..BZ["Azuremyst Isle"] };
		{ "" };
		{ _RED..L["Portals"]..ALC["Hyphen"]..L["Druid Only"] };
		{ GREN.." A) "..BZ["Stormrage Barrow Dens"]..ALC["Comma"]..BZ["Moonglade"] };
		{ GREN.." B) "..BZ["Nordrassil"]..ALC["Comma"]..BZ["Mount Hyjal"] };
		{ GREN.." C) "..BZ["Dream Bough"]..ALC["Comma"]..BZ["Feralas"] };
		{ "" };
		{ _RED..L["Taxi Nodes"] };
		{ BLUE..BZ["Teldrassil"] };
		{ WHIT.." 1) "..BZ["Dolanaar"] };
		{ WHIT.." 2) "..BZ["Darnassus"] };
		{ WHIT.." 3) "..BZ["Rut'theran Village"] };
		{ "" };
		{ BLUE..BZ["Azuremyst Isle"]..ALC["Slash"]..BZ["Bloodmyst Isle"] };
		{ WHIT.." 4) "..BZ["Azure Watch"] };
		{ WHIT.." 5) "..BZ["The Exodar"] };
		{ WHIT.." 6) "..BZ["Blood Watch"] };
		{ "" };
		{ BLUE..BZ["Darkshore"] };
		{ WHIT.." 7) "..BZ["Lor'danel"] };
		{ WHIT.." 8) "..BZ["Grove of the Ancients"] };
		{ "" };
		{ BLUE..BZ["Ashenvale"] };
		{ WHIT.." 9) "..BZ["Blackfathom Camp"] };
		{ WHIT.."10) "..BZ["Astranaar"] };
		{ WHIT.."11) "..BZ["Forest Song"] };
		{ WHIT.."12) "..BZ["Stardust Spire"] };
		{ "" };
		{ BLUE..BZ["Stonetalon Mountains"] };
		{ WHIT.."13) "..BZ["Windshear Hold"] };
		{ WHIT.."14) "..BZ["Mirkfallon Post"] };
		{ WHIT.."15) "..BZ["Thal'darah Overlook"] };
		{ WHIT.."16) "..BZ["Farwatcher's Glen"] };
		{ WHIT.."17) "..BZ["Northwatch Expedition Base Camp"] };
		{ "" };
		{ BLUE..BZ["Desolace"] };
		{ WHIT.."18) "..BZ["Nijel's Point"] };
		{ WHIT.."19) "..BZ["Thunk's Abode"] };
		{ WHIT.."20) "..BZ["Karnum's Glade"] };
		{ WHIT.."21) "..BZ["Ethel Rethor"] };
		{ WHIT.."22) "..BZ["Thargad's Camp"] };
		{ "" };
		{ BLUE..BZ["Feralas"] };
		{ WHIT.."23) "..BZ["Dreamer's Rest"] };
		{ WHIT.."24) "..BZ["Feathermoon"] };
		{ WHIT.."25) "..BZ["Ruins of Feathermoon"] };
		{ WHIT.."26) "..BZ["Tower of Estulan"] };
		{ WHIT.."27) "..BZ["Shadebough"] };
		{ "" };
		{ BLUE..BZ["Northern Barrens"]..ALC["Slash"]..BZ["Southern Barrens"] };
		{ WHIT.."28) "..BZ["Ratchet"] };
		{ WHIT.."29) "..BZ["Honor's Stand"] };
		{ WHIT.."30) "..BZ["Northwatch Hold"] };
		{ WHIT.."31) "..BZ["Fort Triumph"] };
		{ "" };
		{ BLUE..BZ["Dustwallow Marsh"] };
		{ WHIT.."32) "..BZ["Theramore"] };
		{ WHIT.."33) "..BZ["Mudsprocket"] };
		{ "" };
		{ BLUE..BZ["Thousand Needles"] };
		{ WHIT.."34) "..BZ["Fizzle & Pozzik's Speedbarge"] };
		{ "" };
		{ BLUE..BZ["Tanaris"] };
		{ WHIT.."35) "..BZ["Gadgetzan"] };
		{ WHIT.."36) "..BZ["Bootlegger Outpost"] };
		{ WHIT.."37) "..BZ["Gunstan's Dig"] };
		{ "" };
		{ BLUE..BZ["Un'Goro Crater"] };
		{ WHIT.."38) "..BZ["Marshal's Stand"] };
		{ WHIT.."39) "..BZ["Mossy Pile"] };
		{ "" };
		{ BLUE..BZ["Silithus"] };
		{ WHIT.."40) "..BZ["Cenarion Hold"] };
		{ "" };
		{ BLUE..BZ["Felwood"] };
		{ WHIT.."41) "..BZ["Emerald Sanctuary"] };
		{ WHIT.."42) "..BZ["Wildheart Point"] };
		{ WHIT.."43) "..BZ["Whisperwind Grove"] };
		{ WHIT.."44) "..BZ["Talonbranch Glade"] };
		{ "" };
		{ BLUE..BZ["Moonglade"] };
		{ WHIT.."45) "..BZ["Moonglade"] };
		{ WHIT..INDENT..ALC["L-Parenthesis"]..L["South of the path along Lake Elune'ara"]..ALC["R-Parenthesis"] };
		{ GREN.."46) "..BZ["Nighthaven"]..ALC["L-Parenthesis"]..L["Druid Only"]..ALC["R-Parenthesis"] };
		{ "" };
		{ BLUE..BZ["Winterspring"] };
		{ WHIT.."47) "..BZ["Everlook"] };
		{ "" };
		{ BLUE..BZ["Mount Hyjal"] };
		{ WHIT.."48) "..BZ["Nordrassil"] };
		{ WHIT.."49) "..BZ["Shrine of Aviana"] };
		{ WHIT.."50) "..BZ["Shrine of Aessina"] };
		{ WHIT.."51) "..BZ["Sanctuary of Malorne"] };
		{ WHIT.."52) "..BZ["Gates of Sothann"] };
		{ "" };
		{ BLUE..BZ["Uldum"] };
		{ WHIT.."53) "..BZ["Ramkahen"] };
		{ WHIT.."54) "..BZ["Schnottz's Landing"] };
		{ WHIT.."55) "..BZ["Oasis of Vir'sar"] };
		{ "" };
		{ _RED..L["Legend"] };
		{ PURP.."-- : "..L["Portal / Waygate Path to the destination"] };
		{ CYAN.."-- : "..L["Ship / Zeppelin sailing path to destination"] };	
	};
	TransHordeEast = {
		ZoneName = { BZ["Eastern Kingdoms"]..ALC["L-Parenthesis"]..FACTION_HORDE..ALC["R-Parenthesis"] };
		WorldMapID = "14";
		Faction = "Horde";
		{ _RED..L["Zeppelin Towers"]..ALC["Slash"]..BZ["Docks"] };
		{ ORNG.." A') "..BZ["Vengeance Landing"]..ALC["Comma"]..BZ["Howling Fjord"]..ALC["Comma"]..BZ["Northrend"] };
		{ ORNG.." B') "..BZ["Orgrimmar"]..ALC["Comma"]..BZ["Durotar"]..ALC["Comma"]..BZ["Kalimdor"] };
		{ ORNG.." C') "..BZ["Ratchet"]..ALC["Comma"]..BZ["Northern Barrens"]..ALC["Comma"]..BZ["Kalimdor"] };
		{ WHIT.."19) "..BZ["Brill"]..ALC["Comma"]..BZ["Tirisfal Glades"] };
		{ WHIT.."54) "..BZ["Grom'gol Base Camp"]..ALC["Comma"]..BZ["Northern Stranglethorn"] };
		{ WHIT.."56) "..BZ["Booty Bay"]..ALC["Comma"]..BZ["The Cape of Stranglethorn"] };
		{ "" };
		{ _RED..L["Portals"]..ALC["Slash"]..L["Orb of Translocation"] };
		{ PURP.." A) "..BZ["Hellscream's Grasp"]..ALC["Comma"]..BZ["Tol Barad Peninsula"] };
		{ PURP.." B) "..BZ["Baradin Hold"]..ALC["Comma"]..BZ["Tol Barad"] };
		{ GREY..INDENT..ALC["L-Parenthesis"]..L["Only available after winning the PvP battle"]..ALC["R-Parenthesis"] };
		{ PURP.." C) "..BZ["Dragonmaw Port"]..ALC["Comma"]..BZ["Twilight Highlands"] };
		{ PURP.." D) "..BZ["Fuselight-by-the-Sea"]..ALC["Comma"]..BZ["Badlands"] };
		{ GREY..INDENT..ALC["L-Parenthesis"]..L["Transporters by the sea and on the cliff"]..ALC["R-Parenthesis"] };
		{ PURP.." A') "..BZ["The Stair of Destiny"]..ALC["Comma"]..BZ["Hellfire Peninsula"]..ALC["Comma"]..BZ["Outland"] };
		{ PURP.." B') "..BZ["Orgrimmar"]..ALC["Comma"]..BZ["Durotar"]..ALC["Comma"]..BZ["Kalimdor"] };
		{ WHIT.." 3) "..BZ["Sunfury Spire"]..ALC["Comma"]..BZ["Silvermoon City"]..ALC["Comma"]..BZ["Eversong Woods"] };
		{ WHIT.."20) "..BZ["Magic Quarter"]..ALC["Comma"]..BZ["Undercity"]..ALC["Comma"]..BZ["Tirisfal Glades"] };
		{ WHIT.."51) "..BZ["Shattered Landing"]..ALC["Comma"]..BZ["Blasted Lands"] };
		{ "" };
		{ _RED..L["Portals"]..ALC["Hyphen"]..L["Druid Only"] };
		{ GREN.." A) "..BZ["Stormrage Barrow Dens"]..ALC["Comma"]..BZ["Moonglade"] };
		{ GREN.." B) "..BZ["Nordrassil"]..ALC["Comma"]..BZ["Mount Hyjal"] };
		{ GREN.." C) "..BZ["Dream Bough"]..ALC["Comma"]..BZ["Feralas"] };
		{ "" };
		{ _RED..L["Portals"]..ALC["Hyphen"]..L["Druid Only"] };
		{ GREN.." A) "..BZ["Seradane"]..ALC["Comma"]..BZ["The Hinterlands"] };
		{ GREN.." B) "..BZ["Twilight Grove"]..ALC["Comma"]..BZ["Duskwood"] };
		{ "" };
		{ _RED..L["Taxi Nodes"] };
		{ BLUE..BZ["Isle of Quel'Danas"] };
		{ WHIT.." 1) "..BZ["Shattered Sun Staging Area"] };
		{ "" };
		{ BLUE..BZ["Eversong Woods"] };
		{ WHIT.." 2) "..BZ["Falconwing Square"] };
		{ WHIT.." 3) "..BZ["Silvermoon City"] };
		{ WHIT.." 4) "..BZ["Fairbreeze Village"] };
		{ "" };
		{ BLUE..BZ["Ghostlands"] };
		{ WHIT.." 5) "..BZ["Tranquillien"] };
		{ WHIT.." 6) "..BZ["Zul'Aman"] };
		{ "" };
		{ BLUE..BZ["Eastern Plaguelands"] };
		{ GREN.." 7) "..BZ["Acherus: The Ebon Hold"]..ALC["L-Parenthesis"]..L["Death Knight Only"]..ALC["R-Parenthesis"] };
		{ WHIT.." 8) "..BZ["Light's Hope Chapel"] };
		{ WHIT.." 9) "..BZ["Northpass Tower"] };
		{ WHIT.."10) "..BZ["Plaguewood Tower"] };
		{ WHIT.."11) "..BZ["Eastwall Tower"] };
		{ WHIT.."12) "..BZ["Light's Shield Tower"] };
		{ WHIT.."13) "..BZ["Crown Guard Tower"] };
		{ WHIT.."14) "..BZ["Thondroril River"] };
		{ "" };
		{ BLUE..BZ["Western Plaguelands"] };
		{ WHIT.."15) "..BZ["The Menders' Stead"] };
		{ WHIT.."16) "..BZ["Hearthglen"] };
		{ WHIT.."17) "..BZ["Andorhal"] };
		{ "" };
		{ BLUE..BZ["Tirisfal Glades"] };
		{ WHIT.."18) "..BZ["The Bulwark"] };
		{ WHIT.."19) "..BZ["Brill"] };
		{ WHIT.."20) "..BZ["Undercity"] };
		{ "" };
		{ BLUE..BZ["Silverpine Forest"] };
		{ WHIT.."21) "..BZ["Forsaken High Command"] };
		{ WHIT.."22) "..BZ["Forsaken Rear Guard"] };
		{ WHIT.."23) "..BZ["The Sepulcher"] };
		{ WHIT.."24) "..BZ["The Forsaken Front"] };
		{ "" };
		{ BLUE..BZ["Hillsbrad Foothills"] };
		{ WHIT.."25) "..BZ["Southpoint Gate"] };
		{ WHIT.."26) "..BZ["Ruins of Southshore"] };
		{ WHIT.."27) "..BZ["Eastpoint Tower"] };
		{ WHIT.."28) "..BZ["Tarren Mill"] };
		{ WHIT.."29) "..BZ["Strahnbrad"] };
		{ "" };
		{ BLUE..BZ["Arathi Highlands"] };
		{ WHIT.."30) "..BZ["Galen's Fall"] };
		{ WHIT.."31) "..BZ["Hammerfall"] };
		{ "" };
		{ BLUE..BZ["The Hinterlands"] };
		{ WHIT.."32) "..BZ["Hiri'watha Research Station"] };
		{ WHIT.."33) "..BZ["Revantusk Village"] };
		{ "" };
		{ BLUE..BZ["Twilight Highlands"] };
		{ WHIT.."34) "..BZ["Vermillion Redoubt"] };
		{ WHIT.."35) "..BZ["The Gullet"] };
		{ WHIT.."36) "..BZ["Bloodgulch"] };
		{ WHIT.."37) "..BZ["The Krazzworks"] };
		{ WHIT.."38) "..BZ["Dragonmaw Port"] };
		{ WHIT.."39) "..BZ["Crushblow"] };
		{ "" };
		{ BLUE..BZ["Badlands"] };
		{ WHIT.."40) "..BZ["Fuselight"] };
		{ WHIT.."41) "..BZ["Bloodwatcher Point"] };
		{ WHIT.."42) "..BZ["New Kargath"] };
		{ "" };
		{ BLUE..BZ["Searing Gorge"] };
		{ WHIT.."43) "..BZ["Thorium Point"] };
		{ WHIT.."44) "..BZ["Iron Summit"] };
		{ "" };
		{ BLUE..BZ["Burning Steppes"] };
		{ WHIT.."45) "..BZ["Flame Crest"] };
		{ WHIT.."46) "..BZ["Chiselgrip"] };
		{ WHIT.."47) "..BZ["Flamestar Post"] };
		{ PURP.."48) "..BZ["Terror Wing Path"]..ALC["L-Parenthesis"]..L["The Bogpaddle Bullet"]..ALC["R-Parenthesis"] };
		{ "" };
		{ BLUE..BZ["Swamp of Sorrows"] };
		{ WHIT.."49) "..BZ["Bogpaddle"] };
		{ WHIT.."50) "..BZ["Stonard"] };
		{ "" };
		{ BLUE..BZ["Blasted Lands"] };
		{ WHIT.."51) "..BZ["Dreadmaul Hold"] };
		{ WHIT.."52) "..BZ["Shattered Landing"] };
		{ WHIT.."53) "..BZ["Sunveil Excursion"] };
		{ "" };
		{ BLUE..BZ["Northern Stranglethorn"] };
		{ WHIT.."54) "..BZ["Bambala"] };
		{ WHIT.."55) "..BZ["Grom'gol Base Camp"] };
		{ "" };
		{ BLUE..BZ["The Cape of Stranglethorn"] };
		{ WHIT.."56) "..BZ["Hardwrench Hideaway"] };
		{ WHIT.."57) "..BZ["Booty Bay"] };
		{ "" };
		{ BLUE..BZ["Vashj'ir"] };
		{ CYAN.."58) "..BZ["Smuggler's Scar"]..ALC["L-Parenthesis"]..L["Seahorse"]..ALC["R-Parenthesis"] };
		{ CYAN.."59) "..BZ["Sandy Beach"]..ALC["L-Parenthesis"]..L["Seahorse"]..ALC["Slash"]..L["Wind Rider"]..ALC["R-Parenthesis"] };
		{ CYAN.."60) "..BZ["Silver Tide Hollow"]..ALC["L-Parenthesis"]..L["Seahorse"]..ALC["R-Parenthesis"] };
		{ CYAN.."61) "..BZ["Legion's Rest"]..ALC["L-Parenthesis"]..L["Seahorse"]..ALC["R-Parenthesis"] };
		{ CYAN.."62) "..BZ["Stygian Bounty"]..ALC["L-Parenthesis"]..L["Seahorse"]..ALC["Slash"]..L["Wind Rider"]..ALC["R-Parenthesis"] };
		{ CYAN.."63) "..BZ["Tenebrous Cavern"]..ALC["L-Parenthesis"]..L["Seahorse"]..ALC["R-Parenthesis"] };
		{ "" };
		{ _RED..L["Legend"] };
		{ PURP.."-- : "..L["Portal / Waygate Path to the destination"] };
		{ CYAN.."-- : "..L["Ship / Zeppelin sailing path to destination"] };
		{ GREN.."-- : "..L["Special transportation"] };
	};
	TransHordeWest = {
		ZoneName = { BZ["Kalimdor"]..ALC["L-Parenthesis"]..FACTION_HORDE..ALC["R-Parenthesis"] };
		WorldMapID = "13";
		Faction = "Horde";
		{ _RED..L["Zeppelin Towers"]..ALC["Slash"]..BZ["Docks"] };
		{ ORNG.." A') "..BZ["Warsong Hold"]..ALC["Comma"]..BZ["Borean Tundra"]..ALC["Comma"]..BZ["Northrend"] };
		{ ORNG.." B') "..BZ["Undercity"]..ALC["Comma"]..BZ["Tirisfal Glades"]..ALC["Comma"]..BZ["Eastern Kingdoms"] };
		{ ORNG.." C') "..BZ["Grom'gol Base Camp"]..ALC["Comma"]..BZ["Northern Stranglethorn"]..ALC["Comma"]..BZ["Eastern Kingdoms"] };
		{ ORNG.." D') "..BZ["Booty Bay"]..ALC["Comma"]..BZ["The Cape of Stranglethorn"]..ALC["Comma"]..BZ["Eastern Kingdoms"] };
		{ WHIT.." 2) "..BZ["Thunder Bluff"]..ALC["Comma"]..BZ["Mulgore"] };
		{ WHIT.." 5) "..BZ["Orgrimmar"]..ALC["Comma"]..BZ["Durotar"] };
		{ WHIT.."12) "..BZ["Ratchet"]..ALC["Comma"]..BZ["Northern Barrens"] };
		{ "" };
		{ _RED..L["Portals"]..ALC["Slash"]..BZ["Waygate"] };
		{ PURP.." A) "..BZ["Shaper's Terrace"]..ALC["Comma"]..BZ["Un'Goro Crater"] };
		{ PURP.." B) "..BZ["Nordune Ridge"]..ALC["Comma"]..BZ["Mount Hyjal"] };
		{ PURP.." A') "..BZ["Waygate"]..ALC["Comma"]..BZ["Sholazar Basin"]..ALC["Comma"]..BZ["Northrend"] };
		{ PURP.." B') "..BZ["Molten Front"] };
		{ PURP.." C') "..BZ["Temple of Earth"]..ALC["Comma"]..BZ["Deepholm"] };
		{ PURP.." D') "..BZ["Hellscream's Grasp"]..ALC["Comma"]..BZ["Tol Barad Peninsula"]..ALC["Comma"]..BZ["Eastern Kingdoms"] };
		{ PURP.." E') "..BZ["Vashj'ir"]..ALC["Comma"]..BZ["Eastern Kingdoms"] };
		{ PURP.." F') "..BZ["Dragonmaw Port"]..ALC["Comma"]..BZ["Twilight Highlands"]..ALC["Comma"]..BZ["Eastern Kingdoms"] };
		{ PURP.." G') "..BZ["The Stair of Destiny"]..ALC["Comma"]..BZ["Hellfire Peninsula"]..ALC["Comma"]..BZ["Outland"] };
		{ PURP.." H') "..BZ["Honeydew Village"]..ALC["Comma"]..BZ["The Jade Forest"]..ALC["Comma"]..BZ["Pandaria"] };
		{ PURP.." I') "..BZ["Shattered Landing"]..ALC["Comma"]..BZ["Blasted Lands"]..ALC["Comma"]..BZ["Eastern Kingdoms"] };
		{ PURP.." J') "..BZ["Darkmoon Island"] };
		{ PURP.." K') "..BZ["Warspear"]..ALC["Comma"]..BZ["Ashran"]..ALC["Comma"]..BZ["Draenor"] };
		{ WHIT.." 2) "..BZ["Spirit Rise"]..ALC["Comma"]..BZ["Thunder Bluff"]..ALC["Comma"]..BZ["Mulgore"] };
		{ WHIT.." 5) "..BZ["Valley of Spirits"]..ALC["Comma"]..BZ["Orgrimmar"]..ALC["Comma"]..BZ["Durotar"] };
		{ "" };
		{ _RED..L["Taxi Nodes"] };
		{ BLUE..BZ["Mulgore"] };
		{ WHIT.." 1) "..BZ["Bloodhoof Village"] };
		{ WHIT.." 2) "..BZ["Thunder Bluff"] };
		{ "" };
		{ BLUE..BZ["Durotar"] };
		{ WHIT.." 3) "..BZ["Sen'jin Village"] };
		{ WHIT.." 4) "..BZ["Razor Hill"] };
		{ WHIT.." 5) "..BZ["Orgrimmar"] };
		{ "" };
		{ BLUE..BZ["Azshara"] };
		{ WHIT.." 6) "..BZ["Valormok"] };
		{ WHIT.." 7) "..BZ["Southern Rocketway"] };
		{ WHIT.." 8) "..BZ["Bilgewater Harbor"] };
		{ WHIT.." 9) "..BZ["Northern Rocketway"] };
		{ "" };
		{ BLUE..BZ["Northern Barrens"] };
		{ WHIT.."10) "..BZ["Nozzlepot's Outpost"] };
		{ WHIT.."11) "..BZ["Crossroads"] };
		{ WHIT.."12) "..BZ["Ratchet"] };
		{ "" };
		{ BLUE..BZ["Ashenvale"] };
		{ WHIT.."13) "..BZ["The Mor'Shan Ramparts"] };
		{ WHIT.."14) "..BZ["Splintertree Post"] };
		{ WHIT.."15) "..BZ["Silverwind Refuge"] };
		{ WHIT.."16) "..BZ["Hellscream's Watch"] };
		{ WHIT.."17) "..BZ["Zoram'gar Outpost"] };
		{ "" };
		{ BLUE..BZ["Stonetalon Mountains"] };
		{ WHIT.."18) "..BZ["Cliffwalker Post"] };
		{ WHIT.."19) "..BZ["The Sludgewerks"] };
		{ WHIT.."20) "..BZ["Sun Rock Retreat"] };
		{ WHIT.."21) "..BZ["Krom'gar Fortress"] };
		{ WHIT.."22) "..BZ["Malaka'jin"] };
		{ "" };
		{ BLUE..BZ["Desolace"] };
		{ WHIT.."23) "..BZ["Thunk's Abode"] };
		{ WHIT.."24) "..BZ["Karnum's Glade"] };
		{ WHIT.."25) "..BZ["Furien's Post"] };
		{ WHIT.."26) "..BZ["Ethel Rethor"] };
		{ WHIT.."27) "..BZ["Shadowprey Village"] };
		{ "" };
		{ BLUE..BZ["Southern Barrens"] };
		{ WHIT.."28) "..BZ["Hunter's Hill"] };
		{ WHIT.."29) "..BZ["Vendetta Point"] };
		{ WHIT.."30) "..BZ["Desolation Hold"] };
		{ "" };
		{ BLUE..BZ["Dustwallow Marsh"] };
		{ WHIT.."31) "..BZ["Brackenwall Village"] };
		{ WHIT.."32) "..BZ["Mudsprocket"] };
		{ "" };
		{ BLUE..BZ["Feralas"] };
		{ WHIT.."33) "..BZ["Camp Ataya"] };
		{ WHIT.."34) "..BZ["Stonemaul Hold"] };
		{ WHIT.."35) "..BZ["Camp Mojache"] };
		{ "" };
		{ BLUE..BZ["Thousand Needles"] };
		{ WHIT.."36) "..BZ["Westreach Summit"] };
		{ WHIT.."37) "..BZ["Fizzle & Pozzik's Speedbarge"] };
		{ "" };
		{ BLUE..BZ["Tanaris"] };
		{ WHIT.."38) "..BZ["Gadgetzan"] };
		{ WHIT.."39) "..BZ["Bootlegger Outpost"] };
		{ WHIT.."40) "..BZ["Dawnrise Expedition"] };
		{ "" };
		{ BLUE..BZ["Un'Goro Crater"] };
		{ WHIT.."41) "..BZ["Marshal's Stand"] };
		{ WHIT.."42) "..BZ["Mossy Pile"] };
		{ "" };
		{ BLUE..BZ["Silithus"] };
		{ WHIT.."43) "..BZ["Cenarion Hold"] };
		{ "" };
		{ BLUE..BZ["Felwood"] };
		{ WHIT.."44) "..BZ["Emerald Sanctuary"] };
		{ WHIT.."45) "..BZ["Wildheart Point"] };
		{ WHIT.."46) "..BZ["Whisperwind Grove"] };
		{ WHIT.."47) "..BZ["Irontree Clearing"] };
		{ "" };
		{ BLUE..BZ["Moonglade"] };
		{ WHIT.."48) "..BZ["Moonglade"] };
		{ WHIT..INDENT..ALC["L-Parenthesis"]..L["West of the path to Timbermaw Hold"]..ALC["R-Parenthesis"] };
		{ GREN.."49) "..BZ["Nighthaven"]..ALC["L-Parenthesis"]..L["Druid Only"]..ALC["R-Parenthesis"] };
		{ "" };
		{ BLUE..BZ["Winterspring"] };
		{ WHIT.."50) "..BZ["Everlook"] };
		{ "" };
		{ BLUE..BZ["Mount Hyjal"] };
		{ WHIT.."51) "..BZ["Nordrassil"] };
		{ WHIT.."52) "..BZ["Shrine of Aviana"] };
		{ WHIT.."53) "..BZ["Shrine of Aessina"] };
		{ WHIT.."54) "..BZ["Sanctuary of Malorne"] };
		{ WHIT.."55) "..BZ["Gates of Sothann"] };
		{ "" };
		{ BLUE..BZ["Uldum"] };
		{ WHIT.."56) "..BZ["Ramkahen"] };
		{ WHIT.."57) "..BZ["Schnottz's Landing"] };
		{ WHIT.."58) "..BZ["Oasis of Vir'sar"] };
		{ "" };
		{ _RED..L["Legend"] };
		{ PURP.."-- : "..L["Portal / Waygate Path to the destination"] };
		{ CYAN.."-- : "..L["Ship / Zeppelin sailing path to destination"] };	
	};
	TransHordeOrgrimmar = {
		ZoneName = { BZ["Orgrimmar"]..ALC["L-Parenthesis"]..FACTION_HORDE..ALC["R-Parenthesis"] };
		WorldMapID = "321";
		Faction = "Horde";
		LargeMap = "TransHordeOrgrimmar";
		{ _RED..L["Portals"] };
		{ PURP.." A) "..BZ["Shattered Landing"]..ALC["Comma"]..BZ["Blasted Lands"]..ALC["Comma"]..BZ["Eastern Kingdoms"], 10001 };
		{ GREY..INDENT..ALC["L-Parenthesis"]..BZ["Cleft of Shadow"]..ALC["R-Parenthesis"] };
		{ PURP.." B) "..BZ["The Stair of Destiny"]..ALC["Comma"]..BZ["Hellfire Peninsula"]..ALC["Comma"]..BZ["Outland"], 10002 };
		{ GREY..INDENT..ALC["L-Parenthesis"]..BZ["Cleft of Shadow"]..ALC["Slash"]..BZ["Valley of Spirits"]..ALC["R-Parenthesis"] };
		{ PURP.." C) "..BZ["Hellscream's Grasp"]..ALC["Comma"]..BZ["Tol Barad Peninsula"]..ALC["Comma"]..BZ["Eastern Kingdoms"], 10003 };
		{ PURP.." D) "..BZ["Ramkahen"]..ALC["Comma"]..BZ["Uldum"], 10004 };
		{ PURP.." E) "..BZ["Vashj'ir"]..ALC["Comma"]..BZ["Eastern Kingdoms"], 10005 };
		{ PURP.." F) "..BZ["Temple of Earth"]..ALC["Comma"]..BZ["Deepholm"], 10006 };
		{ PURP.." G) "..BZ["Nordrassil"]..ALC["Comma"]..BZ["Mount Hyjal"], 10007 };
		{ PURP.." H) "..BZ["Dragonmaw Port"]..ALC["Comma"]..BZ["Twilight Highlands"]..ALC["Comma"]..BZ["Eastern Kingdoms"], 10008 };
		{ PURP.." I) "..BZ["Honeydew Village"]..ALC["Comma"]..BZ["The Jade Forest"]..ALC["Comma"]..BZ["Pandaria"], 10009 };
		{ PURP.." J) "..BZ["Warspear"]..ALC["Comma"]..BZ["Ashran"]..ALC["Comma"]..BZ["Draenor"], 10010 };
		{ PURP.." K) "..BZ["Dalaran"]..ALC["Comma"]..BZ["Karazhan"], 10016 };
		{ GREY..INDENT..ALC["L-Parenthesis"]..BZ["Cleft of Shadow"]..ALC["Slash"]..BZ["Valley of Spirits"]..ALC["R-Parenthesis"] };
		{ "" };
		{ _RED..L["Zeppelin Towers"] };
		{ ORNG.." A) "..BZ["Thunder Bluff"]..ALC["Comma"]..BZ["Mulgore"], 10011 };
		{ ORNG.." B) "..BZ["Warsong Hold"]..ALC["Comma"]..BZ["Borean Tundra"]..ALC["Comma"]..BZ["Northrend"], 10012 };
		{ ORNG.." C) "..BZ["Undercity"]..ALC["Comma"]..BZ["Tirisfal Glades"]..ALC["Comma"]..BZ["Eastern Kingdoms"], 10013 };
		{ ORNG.." D) "..BZ["Grom'gol Base Camp"]..ALC["Comma"]..BZ["Northern Stranglethorn"]..ALC["Comma"]..BZ["Eastern Kingdoms"], 10014 };
		{ "" };
		{ _RED..L["Taxi Nodes"] };
		{ WHIT.." 1) "..L["Wind Rider Master"], 10015 };
		{ "" };
		{ _RED..ALC["Connection"] };
		{ BLUE.." A) "..BZ["Northern Barrens"], 10017 };
		{ BLUE.." B) "..BZ["Durotar"], 10018 };
		{ BLUE.." C) "..BZ["Azshara"], 10019 };
	};
	TransAllianceOutland = {
		ZoneName = { BZ["Outland"]..ALC["L-Parenthesis"]..FACTION_ALLIANCE..ALC["R-Parenthesis"] };
		WorldMapID = "466";
		Faction = "Alliance";
		{ _RED..L["Portals"]..ALC["Slash"]..L["Transporter"] };
		{ PURP.." A') "..BZ["Stormwind City"]..ALC["Comma"]..BZ["Elwynn Forest"]..ALC["Comma"]..BZ["Eastern Kingdoms"] };
		{ PURP.." B') "..BZ["The Stair of Destiny"]..ALC["Comma"]..BZ["Hellfire Peninsula"]..ALC["Comma"]..BZ["Outland"] };
		{ PURP.." C') "..BZ["Sun's Reach Sanctum"]..ALC["Comma"]..BZ["Isle of Quel'Danas"]..ALC["Comma"]..BZ["Eastern Kingdoms"] };
		{ PURP.." D') "..BZ["Caverns of Time"]..ALC["Comma"]..BZ["Tanaris"]..ALC["Comma"]..BZ["Kalimdor"] };
		{ WHIT.." 1) "..BZ["The Stair of Destiny"]..ALC["Comma"]..BZ["Hellfire Peninsula"] };
		{ WHIT.." 9) "..BZ["Shattrath City"]..ALC["Comma"]..BZ["Terokkar Forest"] };
		{ "" };
		{ _RED..L["Taxi Nodes"] };
		{ BLUE..BZ["Hellfire Peninsula"] };
		{ WHIT.." 1) "..BZ["The Stair of Destiny"] };
		{ WHIT.." 2) "..BZ["Shatter Point"] };
		{ WHIT.." 3) "..BZ["Honor Point"] };
		{ WHIT.." 4) "..BZ["Honor Hold"] };
		{ WHIT.." 5) "..BZ["Temple of Telhamat"] };
		{ "" };
		{ BLUE..BZ["Zangarmarsh"] };
		{ WHIT.." 6) "..BZ["Telredor"] };
		{ WHIT.." 7) "..BZ["Orebor Harborage"] };
		{ "" };
		{ BLUE..BZ["Nagrand"] };
		{ WHIT.." 8) "..BZ["Telaar"] };
		{ "" };
		{ BLUE..BZ["Terokkar Forest"] };
		{ WHIT.." 9) "..BZ["Shattrath City"] };
		{ WHIT.."10) "..BZ["Allerian Stronghold"] };
		{ GREN.."11) "..BZ["Blackwind Landing"] };
		{ GREN..INDENT..ALC["L-Parenthesis"]..L["Requires honored faction with Sha'tari Skyguard"]..ALC["R-Parenthesis"] };
		{ "" };
		{ BLUE..BZ["Shadowmoon Valley"] };
		{ WHIT.."12) "..BZ["Wildhammer Stronghold"] };
		{ GREN.."13) "..BZ["Altar of Sha'tar"]..ALC["L-Parenthesis"]..BF["The Aldor"]..ALC["R-Parenthesis"] };
		{ GREN.."14) "..BZ["Sanctum of the Stars"]..ALC["L-Parenthesis"]..BF["The Scryers"]..ALC["R-Parenthesis"] };
		{ "" };
		{ BLUE..BZ["Blade's Edge Mountains"] };
		{ WHIT.."15) "..BZ["Sylvanaar"] };
		{ WHIT.."16) "..BZ["Evergrove"] };
		{ WHIT.."17) "..BZ["Toshley's Station"] };
		{ GREN.."18) "..BZ["Skyguard Outpost"] };
		{ GREN..INDENT..ALC["L-Parenthesis"]..L["Requires honored faction with Sha'tari Skyguard"]..ALC["R-Parenthesis"] };
		{ "" };
		{ BLUE..BZ["Netherstorm"] };
		{ WHIT.."19) "..BZ["Area 52"] };
		{ WHIT.."20) "..BZ["The Stormspire"] };
		{ WHIT.."21) "..BZ["Cosmowrench"] };
	};
	TransHordeOutland = {
		ZoneName = { BZ["Outland"]..ALC["L-Parenthesis"]..FACTION_HORDE..ALC["R-Parenthesis"] };
		WorldMapID = "466";
		Faction = "Horde";
		{ _RED..L["Portals"]..ALC["Slash"]..L["Transporter"] };
		{ PURP.." A') "..BZ["Orgrimmar"]..ALC["Comma"]..BZ["Durotar"]..ALC["Comma"]..BZ["Kalimdor"] };
		{ PURP.." B') "..BZ["The Stair of Destiny"]..ALC["Comma"]..BZ["Hellfire Peninsula"]..ALC["Comma"]..BZ["Outland"] };
		{ PURP.." C') "..BZ["Sun's Reach Sanctum"]..ALC["Comma"]..BZ["Isle of Quel'Danas"]..ALC["Comma"]..BZ["Eastern Kingdoms"] };
		{ PURP.." D') "..BZ["Caverns of Time"]..ALC["Comma"]..BZ["Tanaris"]..ALC["Comma"]..BZ["Kalimdor"] };
		{ WHIT.." 1) "..BZ["The Stair of Destiny"]..ALC["Comma"]..BZ["Hellfire Peninsula"] };
		{ WHIT.." 8) "..BZ["Shattrath City"]..ALC["Comma"]..BZ["Terokkar Forest"] };
		{ "" };
		{ _RED..L["Taxi Nodes"] };
		{ BLUE..BZ["Hellfire Peninsula"] };
		{ WHIT.." 1) "..BZ["The Stair of Destiny"] };
		{ WHIT.." 2) "..BZ["Thrallmar"] };
		{ WHIT.." 3) "..BZ["Spinebreaker Post"] };
		{ WHIT.." 4) "..BZ["Falcon Watch"] };
		{ "" };
		{ BLUE..BZ["Zangarmarsh"] };
		{ WHIT.." 5) "..BZ["Swamprat Post"] };
		{ WHIT.." 6) "..BZ["Zabra'jin"] };
		{ "" };
		{ BLUE..BZ["Nagrand"] };
		{ WHIT.." 7) "..BZ["Garadar"] };
		{ "" };
		{ BLUE..BZ["Terokkar Forest"] };
		{ WHIT.." 8) "..BZ["Shattrath City"] };
		{ WHIT.." 9) "..BZ["Stonebreaker Hold"] };
		{ GREN.."10) "..BZ["Blackwind Landing"] };
		{ GREN..INDENT..ALC["L-Parenthesis"]..L["Requires honored faction with Sha'tari Skyguard"]..ALC["R-Parenthesis"] };
		{ "" };
		{ BLUE..BZ["Shadowmoon Valley"] };
		{ WHIT.."11) "..BZ["Shadowmoon Village"] };
		{ GREN.."12) "..BZ["Altar of Sha'tar"]..ALC["L-Parenthesis"]..BF["The Aldor"]..ALC["R-Parenthesis"] };
		{ GREN.."13) "..BZ["Sanctum of the Stars"]..ALC["L-Parenthesis"]..BF["The Scryers"]..ALC["R-Parenthesis"] };
		{ "" };
		{ BLUE..BZ["Blade's Edge Mountains"] };
		{ WHIT.."14) "..BZ["Thunderlord Stronghold"] };
		{ WHIT.."15) "..BZ["Evergrove"] };
		{ WHIT.."16) "..BZ["Mok'Nathal Village"] };
		{ GREN.."17) "..BZ["Skyguard Outpost"] };
		{ GREN..INDENT..ALC["L-Parenthesis"]..L["Requires honored faction with Sha'tari Skyguard"]..ALC["R-Parenthesis"] };
		{ "" };
		{ BLUE..BZ["Netherstorm"] };
		{ WHIT.."18) "..BZ["Area 52"] };
		{ WHIT.."19) "..BZ["The Stormspire"] };
		{ WHIT.."20) "..BZ["Cosmowrench"] };
	};
	TransAllianceNorthrend = {
		ZoneName = { BZ["Northrend"]..ALC["L-Parenthesis"]..FACTION_ALLIANCE..ALC["R-Parenthesis"] };
		WorldMapID = "485";
		Faction = "Alliance";
		{ _RED..BZ["Docks"] };
		{ ORNG.." A') "..BZ["Stormwind City"]..ALC["Comma"]..BZ["Elwynn Forest"]..ALC["Comma"]..BZ["Eastern Kingdoms"] };
		{ ORNG.." B') "..BZ["Menethil Harbor"]..ALC["Comma"]..BZ["Wetlands"]..ALC["Comma"]..BZ["Eastern Kingdoms"] };
		{ WHIT.." 1) "..BZ["Valiance Keep"]..ALC["Comma"]..BZ["Borean Tundra"] };
		{ WHIT.." 5) "..BZ["Unu'pe"]..ALC["Comma"]..BZ["Borean Tundra"] };
		{ WHIT.." 9) "..BZ["Moa'ki Harbor"]..ALC["Comma"]..BZ["Dragonblight"] };
		{ WHIT.."14) "..BZ["Kamagua"]..ALC["Comma"]..BZ["Howling Fjord"] };
		{ WHIT.."15) "..BZ["Valgarde"]..ALC["Comma"]..BZ["Howling Fjord"] };
		{ "" };
		{ _RED..L["Portals"]..ALC["Slash"]..BZ["Waygate"] };
		{ PURP.." A) "..BZ["Waygate"]..ALC["Comma"]..BZ["Sholazar Basin"] };
		{ PURP.." B) "..BZ["Wintergrasp Fortress"]..ALC["Comma"]..BZ["Wintergrasp"] };
		{ PURP.." C) "..BZ["Violet Stand"]..ALC["Comma"]..BZ["Crystalsong Forest"] };
		{ PURP.." D) "..BZ["Garm's Rise"]..ALC["Comma"]..BZ["The Storm Peaks"] };
		{ PURP.." A') "..BZ["Shaper's Terrace"]..ALC["Comma"]..BZ["Un'Goro Crater"]..ALC["Comma"]..BZ["Kalimdor"] };
		{ PURP.." B') "..BZ["Caverns of Time"]..ALC["Comma"]..BZ["Tanaris"]..ALC["Comma"]..BZ["Kalimdor"] };
		{ PURP.." C') "..BZ["Stormwind City"]..ALC["Comma"]..BZ["Elwynn Forest"]..ALC["Comma"]..BZ["Eastern Kingdoms"] };
		{ WHIT.."25) "..BZ["Dalaran"]..ALC["Comma"]..BZ["Crystalsong Forest"] };
		{ WHIT.."27) "..BZ["K3"]..ALC["Comma"]..BZ["The Storm Peaks"] };
		{ "" };
		{ _RED..L["Portals"]..ALC["Hyphen"]..L["Druid Only"] };
		{ GREN.." A) "..BZ["Grizzly Hills"]..GREY.." (50.38, 29.40)" };
		{ "" };
		{ _RED..L["Taxi Nodes"] };
		{ BLUE..BZ["Borean Tundra"] };
		{ WHIT.." 1) "..BZ["Valiance Keep"] };
		{ WHIT.." 2) "..BZ["Amber Ledge"] };
		{ "" };
		{ BLUE..BZ["Coldarra"] };
		{ WHIT.." 3) "..BZ["Transitus Shield"] };
		{ "" };
		{ BLUE..BZ["Borean Tundra"] };
		{ WHIT.." 4) "..BZ["Fizzcrank Airstrip"] };
		{ WHIT.." 5) "..BZ["Unu'pe"] };
		{ "" };
		{ BLUE..BZ["Sholazar Basin"] };
		{ WHIT.." 6) "..BZ["Nesingwary Base Camp"] };
		{ WHIT.." 7) "..BZ["River's Heart"] };
		{ "" };
		{ BLUE..BZ["Dragonblight"] };
		{ WHIT.." 8) "..BZ["Stars' Rest"] };
		{ WHIT.." 9) "..BZ["Moa'ki Harbor"] };
		{ WHIT.."10) "..BZ["Fordragon Hold"] };
		{ WHIT.."11) "..BZ["Wyrmrest Temple"] };
		{ WHIT.."12) "..BZ["Wintergarde Keep"] };
		{ "" };
		{ BLUE..BZ["Howling Fjord"] };
		{ WHIT.."13) "..BZ["Westguard Keep"] };
		{ WHIT.."14) "..BZ["Kamagua"] };
		{ WHIT.."15) "..BZ["Valgarde"] };
		{ WHIT.."16) "..BZ["Fort Wildervar"] };
		{ "" };
		{ BLUE..BZ["Grizzly Hills"] };
		{ WHIT.."17) "..BZ["Amberpine Lodge"] };
		{ WHIT.."18) "..BZ["Westfall Brigade Encampment"] };
		{ "" };
		{ BLUE..BZ["Zul'Drak"] };
		{ WHIT.."19) "..BZ["Gundrak"] };
		{ WHIT.."20) "..BZ["Zim'Torga"] };
		{ WHIT.."21) "..BZ["The Argent Stand"] };
		{ WHIT.."22) "..BZ["Light's Breach"] };
		{ WHIT.."23) "..BZ["Ebon Watch"] };
		{ "" };
		{ BLUE..BZ["Crystalsong Forest"] };
		{ WHIT.."24) "..BZ["Windrunner's Overlook"] };
		{ WHIT.."25) "..BZ["Dalaran"] };
		{ "" };
		{ BLUE..BZ["The Storm Peaks"] };
		{ WHIT.."26) "..BZ["Frosthold"] };
		{ WHIT.."27) "..BZ["K3"] };
		{ WHIT.."28) "..BZ["Bouldercrag's Refuge"] };
		{ WHIT.."29) "..BZ["Ulduar"] };
		{ WHIT.."30) "..BZ["Dun Niffelem"] };
		{ "" };
		{ BLUE..BZ["Icecrown"] };
		{ WHIT.."31) "..BZ["The Argent Vanguard"] };
		{ WHIT.."32) "..BZ["Crusaders' Pinnacle"] };
		{ WHIT.."33) "..BZ["Argent Tournament Grounds"] };
		{ WHIT.."34) "..BZ["The Shadow Vault"] };
		{ WHIT.."35) "..BZ["Death's Rise"] };
		{ "" };
		{ BLUE..BZ["Wintergrasp"] };
		{ WHIT.."36) "..BZ["Valiance Landing Camp"] };
		{ "" };
		{ _RED..L["Legend"] };
		{ PURP.."-- : "..L["Portal / Waygate Path to the destination"] };
		{ CYAN.."-- : "..L["Ship / Zeppelin sailing path to destination"] };	
	};
	TransHordeNorthrend = {
		ZoneName = { BZ["Northrend"]..ALC["L-Parenthesis"]..FACTION_HORDE..ALC["R-Parenthesis"] };
		WorldMapID = "485";
		Faction = "Horde";
		{ _RED..L["Zeppelin Towers"] };
		{ ORNG.." A') "..BZ["Orgrimmar"]..ALC["Comma"]..BZ["Durotar"]..ALC["Comma"]..BZ["Kalimdor"] };
		{ ORNG.." B') "..BZ["Undercity"]..ALC["Comma"]..BZ["Tirisfal Glades"]..ALC["Comma"]..BZ["Eastern Kingdoms"] };
		{ WHIT.." 1) "..BZ["Warsong Hold"]..ALC["Comma"]..BZ["Borean Tundra"] };
		{ WHIT.." 6) "..BZ["Unu'pe"]..ALC["Comma"]..BZ["Borean Tundra"] };
		{ WHIT.."10) "..BZ["Moa'ki Harbor"]..ALC["Comma"]..BZ["Dragonblight"] };
		{ WHIT.."14) "..BZ["Kamagua"]..ALC["Comma"]..BZ["Howling Fjord"] };
		{ WHIT.."16) "..BZ["Vengeance Landing"]..ALC["Comma"]..BZ["Howling Fjord"] };
		{ "" };
		{ _RED..L["Portals"]..ALC["Slash"]..BZ["Waygate"] };
		{ PURP.." A) "..BZ["Waygate"]..ALC["Comma"]..BZ["Sholazar Basin"] };
		{ PURP.." B) "..BZ["Wintergrasp Fortress"]..ALC["Comma"]..BZ["Wintergrasp"] };
		{ PURP.." C) "..BZ["Violet Stand"]..ALC["Comma"]..BZ["Crystalsong Forest"] };
		{ PURP.." D) "..BZ["Garm's Rise"]..ALC["Comma"]..BZ["The Storm Peaks"] };
		{ PURP.." A') "..BZ["Shaper's Terrace"]..ALC["Comma"]..BZ["Un'Goro Crater"]..ALC["Comma"]..BZ["Kalimdor"] };
		{ PURP.." B') "..BZ["Caverns of Time"]..ALC["Comma"]..BZ["Tanaris"]..ALC["Comma"]..BZ["Kalimdor"] };
		{ PURP.." C') "..BZ["Orgrimmar"]..ALC["Comma"]..BZ["Durotar"]..ALC["Comma"]..BZ["Kalimdor"] };
		{ WHIT.."27) "..BZ["Dalaran"]..ALC["Comma"]..BZ["Crystalsong Forest"] };
		{ WHIT.."28) "..BZ["K3"]..ALC["Comma"]..BZ["The Storm Peaks"] };
		{ "" };
		{ _RED..L["Portals"]..ALC["Hyphen"]..L["Druid Only"] };
		{ GREN.." A) "..BZ["Grizzly Hills"]..GREY.." (50.38, 29.40)" };
		{ "" };
		{ _RED..L["Taxi Nodes"] };
		{ BLUE..BZ["Borean Tundra"] };
		{ WHIT.." 1) "..BZ["Warsong Hold"] };
		{ WHIT.." 2) "..BZ["Amber Ledge"] };
		{ "" };
		{ BLUE..BZ["Coldarra"] };
		{ WHIT.." 3) "..BZ["Transitus Shield"] };
		{ "" };
		{ BLUE..BZ["Borean Tundra"] };
		{ WHIT.." 4) "..BZ["Bor'gorok Outpost"] };
		{ WHIT.." 5) "..BZ["Taunka'le Village"] };
		{ WHIT.." 6) "..BZ["Unu'pe"] };
		{ "" };
		{ BLUE..BZ["Sholazar Basin"] };
		{ WHIT.." 7) "..BZ["Nesingwary Base Camp"] };
		{ WHIT.." 8) "..BZ["River's Heart"] };
		{ "" };
		{ BLUE..BZ["Dragonblight"] };
		{ WHIT.." 9) "..BZ["Agmar's Hammer"] };
		{ WHIT.."10) "..BZ["Moa'ki Harbor"] };
		{ WHIT.."11) "..BZ["Kor'kron Vanguard"] };
		{ WHIT.."12) "..BZ["Wyrmrest Temple"] };
		{ WHIT.."13) "..BZ["Venomspite"] };
		{ "" };
		{ BLUE..BZ["Howling Fjord"] };
		{ WHIT.."14) "..BZ["Kamagua"] };
		{ WHIT.."15) "..BZ["New Agamand"] };
		{ WHIT.."16) "..BZ["Vengeance Landing"] };
		{ WHIT.."17) "..BZ["Apothecary Camp"] };
		{ WHIT.."18) "..BZ["Camp Winterhoof"] };
		{ "" };
		{ BLUE..BZ["Grizzly Hills"] };
		{ WHIT.."19) "..BZ["Conquest Hold"] };
		{ WHIT.."20) "..BZ["Camp Oneqwah"] };
		{ "" };
		{ BLUE..BZ["Zul'Drak"] };
		{ WHIT.."21) "..BZ["Gundrak"] };
		{ WHIT.."22) "..BZ["Zim'Torga"] };
		{ WHIT.."23) "..BZ["The Argent Stand"] };
		{ WHIT.."24) "..BZ["Light's Breach"] };
		{ WHIT.."25) "..BZ["Ebon Watch"] };
		{ "" };
		{ BLUE..BZ["Crystalsong Forest"] };
		{ WHIT.."26) "..BZ["Sunreaver's Command"] };
		{ WHIT.."27) "..BZ["Dalaran"] };
		{ "" };
		{ BLUE..BZ["The Storm Peaks"] };
		{ WHIT.."28) "..BZ["K3"] };
		{ WHIT.."29) "..BZ["Camp Tunka'lo"] };
		{ WHIT.."30) "..BZ["Grom'arsh Crash-Site"] };
		{ WHIT.."31) "..BZ["Bouldercrag's Refuge"] };
		{ WHIT.."32) "..BZ["Ulduar"] };
		{ WHIT.."33) "..BZ["Dun Niffelem"] };
		{ "" };
		{ BLUE..BZ["Icecrown"] };
		{ WHIT.."34) "..BZ["The Argent Vanguard"] };
		{ WHIT.."35) "..BZ["Crusaders' Pinnacle"] };
		{ WHIT.."36) "..BZ["Argent Tournament Grounds"] };
		{ WHIT.."37) "..BZ["The Shadow Vault"] };
		{ WHIT.."38) "..BZ["Death's Rise"] };
		{ "" };
		{ BLUE..BZ["Wintergrasp"] };
		{ WHIT.."39) "..BZ["Warsong Camp"] };
		{ "" };
		{ _RED..L["Legend"] };
		{ PURP.."-- : "..L["Portal / Waygate Path to the destination"] };
		{ CYAN.."-- : "..L["Ship / Zeppelin sailing path to destination"] };	
	};
	TransDeepholm = {
		ZoneName = { BZ["Deepholm"] };
		WorldMapID = "640";
		{ _RED..L["Portals"] };
		{ PURP.." A) "..BZ["Temple of Earth"] };
		{ PURP.." B) "..BZ["Therazane's Throne"] };
		{ PURP.." A') "..BZ["Stormwind City"]..ALC["Comma"]..BZ["Elwynn Forest"]..ALC["Comma"]..BZ["Eastern Kingdoms"] };
		{ PURP.." B') "..BZ["Orgrimmar"]..ALC["Comma"]..BZ["Durotar"]..ALC["Comma"]..BZ["Kalimdor"] };
		{ "" };
		{ _RED..L["Legend"] };
		{ PURP.."-- : "..L["Portal / Waygate Path to the destination"] };
		
	};
	DarkmoonFaire = {
		ZoneName = { BZ["Darkmoon Island"] };
		WorldMapID = "823";
		{ PURP.." A) "..L["Portals"] };
		{ PURP..INDENT.." -> "..BZ["Elwynn Forest"] };
		{ PURP..INDENT.." -> "..BZ["Mulgore"] };
	};
	TransAlliancePandaria = {
		ZoneName = { BZ["Pandaria"]..ALC["L-Parenthesis"]..FACTION_ALLIANCE..ALC["R-Parenthesis"] };
		WorldMapID = "862";
		Faction = "Alliance";
		{ _RED..L["Portals"] };
		{ PURP.." A) "..BZ["Paw'Don Village"]..ALC["Comma"]..BZ["The Jade Forest"] };
		{ PURP.." B) "..BZ["Violet Rise"]..ALC["Comma"]..BZ["Isle of Thunder"] };
		{ PURP.." C) "..BZ["Shan'ze Dao"]..ALC["Comma"]..BZ["Townlong Steppes"] };
		{ PURP.." D) "..BZ["The Skyfire"]..ALC["Comma"]..BZ["Krasarang Wilds"] };
		{ PURP.." A') "..BZ["Stormwind City"]..ALC["Comma"]..BZ["Elwynn Forest"]..ALC["Comma"]..BZ["Eastern Kingdoms"] };
		{ PURP.." B') "..BZ["Ironforge"]..ALC["Comma"]..BZ["Dun Morogh"]..ALC["Comma"]..BZ["Eastern Kingdoms"] };
		{ PURP.." C') "..BZ["Dalaran"]..ALC["Comma"]..BZ["Crystalsong Forest"]..ALC["Comma"]..BZ["Northrend"] };
		{ PURP.." D') "..BZ["The Exodar"]..ALC["Comma"]..BZ["Azuremyst Isle"]..ALC["Comma"]..BZ["Kalimdor"] };
		{ PURP.." E') "..BZ["Darnassus"]..ALC["Comma"]..BZ["Teldrassil"]..ALC["Comma"]..BZ["Kalimdor"] };
		{ PURP.." F') "..BZ["Ratchet"]..ALC["Comma"]..BZ["Northern Barrens"]..ALC["Comma"]..BZ["Kalimdor"] };
		{ PURP.." G') "..BZ["Shattrath City"]..ALC["Comma"]..BZ["Terokkar Forest"]..ALC["Comma"]..BZ["Outland"] };
		{ "" };
		{ _RED..L["Special transportation"] };
		{ ORNG.." A) "..BZ["The Arboretum"]..ALC["Comma"]..BZ["The Jade Forest"] };
		{ INDENT..GREY..L["Abandoned Kite"]..ALC["L-Parenthesis"]..L["From sea level to ground level"]..ALC["R-Parenthesis"] };
		{ ORNG.." B) "..BZ["Thunder Hold"]..ALC["Comma"]..BZ["The Jade Forest"] };
		{ INDENT..GREY..L["Abandoned Kite"]..ALC["L-Parenthesis"]..L["From sea level to ground level"]..ALC["R-Parenthesis"] };
		{ ORNG.." C) "..BZ["Strongarm Airstrip"]..ALC["Comma"]..BZ["The Jade Forest"]..ALC["Slash"]..BZ["Serenity Falls"] };
		{ INDENT..GREY..L["Abandoned Kite"]..ALC["L-Parenthesis"]..L["From sea level to ground level"]..ALC["R-Parenthesis"] };
		{ ORNG.." D) "..BZ["Winds' Edge"]..ALC["Comma"]..BZ["Valley of the Four Winds"]..ALC["Slash"]..BZ["The Deepwild"]..ALC["Comma"]..BZ["Krasarang Wilds"] };
		{ INDENT..GREY..L["Rappelling Rope"]..ALC["Slash"]..L["Climbing Rope"] };
		{ ORNG.." E) "..BZ["Whispercloud Rise"]..ALC["Slash"]..BZ["Zouchin Province"]..ALC["Comma"]..BZ["Kun-Lai Summit"] };
		{ INDENT..GREY..L["Whispercloud's Balloon"] };
		{ ORNG.." F) "..BZ["Serpent's Spine"]..ALC["Comma"]..BZ["Vale of Eternal Blossoms"]..ALC["Slash"]..BZ["Terrace of Gurthan"]..ALC["Comma"]..BZ["Dread Wastes"] };
		{ INDENT..GREY..L["Shado-Pan Rope"] };
		{ "" };
		{ _RED..L["Taxi Nodes"] };
		{ BLUE..BZ["The Jade Forest"] };
		{ WHIT.." 1) "..BZ["Paw'Don Village"] };
		{ WHIT.." 2) "..BZ["Pearlfin Village"] };
		{ WHIT.." 3) "..BZ["Serpent's Overlook"] };
		{ WHIT.." 4) "..BZ["Jade Temple Grounds"] };
		{ WHIT.." 5) "..BZ["Dawn's Blossom"] };
		{ WHIT.." 6) "..BZ["The Arboretum"] };
		{ WHIT.." 7) "..BZ["Tian Monastery"] };
		{ WHIT.." 8) "..BZ["Emperor's Omen"] };
		{ WHIT.." 9) "..BZ["Sri-La Village"] };
		{ "" };
		{ BLUE..BZ["Valley of the Four Winds"] };
		{ WHIT.."10) "..BZ["Pang's Stead"] };
		{ WHIT.."11) "..BZ["Grassy Cline"] };
		{ WHIT.."12) "..BZ["Halfhill"] };
		{ WHIT.."13) "..BZ["Stoneplow"] };
		{ "" };
		{ BLUE..BZ["Krasarang Wilds"] };
		{ WHIT.."14) "..BZ["Sentinel Basecamp"] };
		{ WHIT.."15) "..BZ["Cradle of Chi-Ji"] };
		{ WHIT.."16) "..BZ["Marista"] };
		{ WHIT.."17) "..BZ["The Incursion"] };
		{ WHIT.."18) "..BZ["Zhu's Watch"] };
		{ WHIT.."19) "..BZ["Lion's Landing"] };
		{ GREY..INDENT..L["Require to complete \"Meet the Scout\" quest line first."] };
		{ "" };
		{ BLUE..BZ["The Veiled Stair"] };
		{ WHIT.."20) "..BZ["Tavern in the Mists"] };
		{ "" };
		{ BLUE..BZ["Kun-Lai Summit"] };
		{ WHIT.."21) "..BZ["Binan Village"] };
		{ WHIT.."22) "..BZ["Westwind Rest"] };
		{ WHIT.."23) "..BZ["Shado-Pan Fallback"] };
		{ WHIT.."24) "..BZ["Kota Basecamp"] };
		{ WHIT.."25) "..BZ["Winter's Blossom"] };
		{ WHIT.."26) "..BZ["One Keg"] };
		{ WHIT.."27) "..BZ["Temple of the White Tiger"] };
		{ WHIT.."28) "..BZ["Zouchin Village"] };
		{ "" };
		{ BLUE..BZ["Townlong Steppes"] };
		{ WHIT.."29) "..BZ["Longying Outpost"] };
		{ WHIT.."30) "..BZ["Gao-Ran Battlefront"] };
		{ WHIT.."31) "..BZ["Rensai's Watchpost"] };
		{ WHIT.."32) "..BZ["Shado-Pan Garrison"] };
		{ "" };
		{ BLUE..BZ["Dread Wastes"] };
		{ WHIT.."33) "..BZ["The Sunset Brewgarden"] };
		{ WHIT.."34) "..BZ["Klaxxi'vess"] };
		{ WHIT.."35) "..BZ["The Lion's Redoubt"] };
		{ WHIT.."36) "..BZ["The Briny Muck"] };
		{ WHIT.."37) "..BZ["Soggy's Gamble"] };
		{ "" };
		{ BLUE..BZ["Vale of Eternal Blossoms"] };
		{ WHIT.."38) "..BZ["Serpent's Spine"] };
		{ WHIT.."39) "..BZ["Shrine of Seven Stars"] };
		{ "" };
		{ BLUE..BZ["Isle of Giants"] };
		{ WHIT.."40) "..BZ["Beeble's Wreck"] };
		{ "" };
		{ BLUE..BZ["Timeless Isle"] };
		{ WHIT.."41) "..BZ["Tushui Landing"] };
		{ "" };
		{ _RED..L["Legend"] };
		{ PURP.."-- : "..L["Portal / Waygate Path to the destination"] };
	};
	TransHordePandaria = {
		ZoneName = { BZ["Pandaria"]..ALC["L-Parenthesis"]..FACTION_HORDE..ALC["R-Parenthesis"] };
		WorldMapID = "862";
		Faction = "Horde";
		{ _RED..L["Portals"] };
		{ PURP.." A) "..BZ["Honeydew Village"]..ALC["Comma"]..BZ["The Jade Forest"] };
		{ PURP.." B) "..BZ["Dawnseeker Promontory"]..ALC["Comma"]..BZ["Isle of Thunder"] };
		{ PURP.." C) "..BZ["Shan'ze Dao"]..ALC["Comma"]..BZ["Townlong Steppes"] };
		{ PURP.." D) "..BZ["Sparkrocket Outpost"]..ALC["Comma"]..BZ["Krasarang Wilds"] };
		{ PURP.." E) "..BZ["Ruins of Ogudei"]..ALC["Comma"]..BZ["Krasarang Wilds"] };
		{ PURP.." A') "..BZ["Orgrimmar"]..ALC["Comma"]..BZ["Durotar"]..ALC["Comma"]..BZ["Kalimdor"] };
		{ PURP.." B') "..BZ["Thunder Bluff"]..ALC["Comma"]..BZ["Mulgore"]..ALC["Comma"]..BZ["Kalimdor"] };
		{ PURP.." C') "..BZ["Ratchet"]..ALC["Comma"]..BZ["Northern Barrens"]..ALC["Comma"]..BZ["Kalimdor"] };
		{ PURP.." D') "..BZ["Shattrath City"]..ALC["Comma"]..BZ["Terokkar Forest"]..ALC["Comma"]..BZ["Outland"] };
		{ PURP.." E') "..BZ["Dalaran"]..ALC["Comma"]..BZ["Crystalsong Forest"]..ALC["Comma"]..BZ["Northrend"] };
		{ PURP.." F') "..BZ["Silvermoon City"]..ALC["Comma"]..BZ["Eversong Woods"]..ALC["Comma"]..BZ["Eastern Kingdoms"] };
		{ PURP.." G') "..BZ["Undercity"]..ALC["Comma"]..BZ["Tirisfal Glades"]..ALC["Comma"]..BZ["Eastern Kingdoms"] };
		{ "" };
		{ _RED..L["Special transportation"] };
		{ ORNG.." A) "..BZ["The Arboretum"]..ALC["Comma"]..BZ["The Jade Forest"] };
		{ INDENT..GREY..L["Abandoned Kite"]..ALC["L-Parenthesis"]..L["From sea level to ground level"]..ALC["R-Parenthesis"] };
		{ ORNG.." B) "..BZ["Thunder Hold"]..ALC["Comma"]..BZ["The Jade Forest"] };
		{ INDENT..GREY..L["Abandoned Kite"]..ALC["L-Parenthesis"]..L["From sea level to ground level"]..ALC["R-Parenthesis"] };
		{ ORNG.." C) "..BZ["Strongarm Airstrip"]..ALC["Comma"]..BZ["The Jade Forest"]..ALC["Slash"]..BZ["Serenity Falls"] };
		{ INDENT..GREY..L["Abandoned Kite"]..ALC["L-Parenthesis"]..L["From sea level to ground level"]..ALC["R-Parenthesis"] };
		{ ORNG.." D) "..BZ["Winds' Edge"]..ALC["Comma"]..BZ["Valley of the Four Winds"]..ALC["Slash"]..BZ["The Deepwild"]..ALC["Comma"]..BZ["Krasarang Wilds"] };
		{ INDENT..GREY..L["Rappelling Rope"]..ALC["Slash"]..L["Climbing Rope"] };
		{ ORNG.." E) "..BZ["Whispercloud Rise"]..ALC["Slash"]..BZ["Zouchin Province"]..ALC["Comma"]..BZ["Kun-Lai Summit"] };
		{ INDENT..GREY..L["Whispercloud's Balloon"] };
		{ ORNG.." F) "..BZ["Serpent's Spine"]..ALC["Comma"]..BZ["Vale of Eternal Blossoms"]..ALC["Slash"]..BZ["Terrace of Gurthan"]..ALC["Comma"]..BZ["Dread Wastes"] };
		{ INDENT..GREY..L["Shado-Pan Rope"] };
		{ "" };
		{ _RED..L["Taxi Nodes"] };
		{ BLUE..BZ["The Jade Forest"] };
		{ WHIT.." 1) "..BZ["Honeydew Village"] };
		{ WHIT.." 2) "..BZ["Tian Monastery"] };
		{ WHIT.." 3) "..BZ["Emperor's Omen"] };
		{ WHIT.." 4) "..BZ["Sri-La Village"] };
		{ WHIT.." 5) "..BZ["Dawn's Blossom"] };
		{ WHIT.." 6) "..BZ["The Arboretum"] };
		{ WHIT.." 7) "..BZ["Jade Temple Grounds"] };
		{ WHIT.." 8) "..BZ["Serpent's Overlook"] };
		{ WHIT.." 9) "..BZ["Grookin Hill"] };
		{ "" };
		{ BLUE..BZ["Valley of the Four Winds"] };
		{ WHIT.."10) "..BZ["Pang's Stead"] };
		{ WHIT.."11) "..BZ["Grassy Cline"] };
		{ WHIT.."12) "..BZ["Halfhill"] };
		{ WHIT.."13) "..BZ["Stoneplow"] };
		{ "" };
		{ BLUE..BZ["Krasarang Wilds"] };
		{ WHIT.."14) "..BZ["Dawnchaser Retreat"] };
		{ WHIT.."15) "..BZ["Cradle of Chi-Ji"] };
		{ WHIT.."16) "..BZ["Marista"] };
		{ WHIT.."17) "..BZ["Thunder Cleft"] };
		{ WHIT.."18) "..BZ["Zhu's Watch"] };
		{ WHIT.."19) "..BZ["Domination Point"] };
		{ GREY..INDENT..L["Require to complete \"Meet the Scout\" quest line first."] };
		{ "" };
		{ BLUE..BZ["The Veiled Stair"] };
		{ WHIT.."20) "..BZ["Tavern in the Mists"] };
		{ "" };
		{ BLUE..BZ["Kun-Lai Summit"] };
		{ WHIT.."21) "..BZ["Binan Village"] };
		{ WHIT.."22) "..BZ["Eastwind Rest"] };
		{ WHIT.."23) "..BZ["Shado-Pan Fallback"] };
		{ WHIT.."24) "..BZ["Kota Basecamp"] };
		{ WHIT.."25) "..BZ["Winter's Blossom"] };
		{ WHIT.."26) "..BZ["One Keg"] };
		{ WHIT.."27) "..BZ["Temple of the White Tiger"] };
		{ WHIT.."28) "..BZ["Zouchin Village"] };
		{ WHIT.."29) "..BZ["Serpent's Spine"] };
		{ "" };
		{ BLUE..BZ["Townlong Steppes"] };
		{ WHIT.."30) "..BZ["Longying Outpost"] };
		{ WHIT.."31) "..BZ["Gao-Ran Battlefront"] };
		{ WHIT.."32) "..BZ["Rensai's Watchpost"] };
		{ WHIT.."33) "..BZ["Shado-Pan Garrison"] };
		{ "" };
		{ BLUE..BZ["Dread Wastes"] };
		{ WHIT.."34) "..BZ["The Sunset Brewgarden"] };
		{ WHIT.."35) "..BZ["Klaxxi'vess"] };
		{ WHIT.."36) "..BZ["The Briny Muck"] };
		{ WHIT.."37) "..BZ["Soggy's Gamble"] };
		{ "" };
		{ BLUE..BZ["Vale of Eternal Blossoms"] };
		{ WHIT.."38) "..BZ["Serpent's Spine"] };    
		{ WHIT.."39) "..BZ["Shrine of Two Moons"] };
		{ "" };
		{ BLUE..BZ["Isle of Giants"] };
		{ WHIT.."40) "..BZ["Bozzle's Wreck"] };
		{ "" };
		{ BLUE..BZ["Timeless Isle"] };
		{ WHIT.."41) "..BZ["Huojin Landing"] };
		{ "" };
		{ _RED..L["Legend"] };
		{ PURP.."-- : "..L["Portal / Waygate Path to the destination"] };
	};
	TransEmeraldDreamway = {
		ZoneName = { BZ["Emerald Dreamway"]..ALC["L-Parenthesis"]..L["Druid Only"]..ALC["R-Parenthesis"] };
		WorldMapID = "1048";
		{ _RED..L["Portals"] };
		{ GREN.." A) "..BZ["The Dreamgrove"]..ALC["Comma"]..BZ["Val'sharah"]..ALC["Comma"]..BZ["Broken Isles"], 10001 };
		{ GREN.." B) "..BZ["Grizzly Hills"]..ALC["Comma"]..BZ["Northrend"], 10002 };
		{ GREN.." C) "..BZ["Dream Bough"]..ALC["Comma"]..BZ["Feralas"]..ALC["Comma"]..BZ["Kalimdor"], 10003 };
		{ GREN.." D) "..BZ["Stormrage Barrow Dens"]..ALC["Comma"]..BZ["Moonglade"]..ALC["Comma"]..BZ["Kalimdor"], 10004 };
		{ GREN.." E) "..BZ["Twilight Grove"]..ALC["Comma"]..BZ["Duskwood"]..ALC["Comma"]..BZ["Eastern Kingdoms"], 10005 };
		{ GREN.." F) "..BZ["Seradane"]..ALC["Comma"]..BZ["The Hinterlands"]..ALC["Comma"]..BZ["Eastern Kingdoms"], 10006 };
		{ GREN.." G) "..BZ["Nordrassil"]..ALC["Comma"]..BZ["Mount Hyjal"]..ALC["Comma"]..BZ["Kalimdor"], 10007 };
	};
};

Atlas_RegisterPlugin("Atlas_Transportation", myCategory, myData);

